#
# spec file for package gdm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define enable_split_authentication 1

# special hack for SLE15/Leap 15: it does not yet know /usr/etc, and files in /etc should be %%config
%if 0%{?suse_version} >= 1550
  %define _config_norepl %nil
%else
  %define _pam_vendordir %{_sysconfdir}/pam.d
  %define _config_norepl %config(noreplace)
%endif

Name:           gdm
Version:        48.0
Release:        10.1
Summary:        The GNOME Display Manager
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/GDM

Source0:        %{name}-%{version}.tar.zst
Source1:        gdm.pamd
Source2:        gdm-autologin.pamd
Source3:        gdm-launch-environment.pamd
Source4:        gdm-fingerprint.pamd
Source5:        gdm-smartcard.pamd
# gdmflexiserver wrapper, to enable other display managers to abuse the gdmflexiserver namespace (like lightdm)
Source6:        gdmflexiserver-wrapper
# /etc/xinit.d/xdm integration script
Source7:        X11-displaymanager-gdm
# Use tmpfiles to create directories under /var to support transactional updates
Source9:        gdm.tmpfiles
# Use reserveVT.conf to make autologin user session not to select tty1
Source10:       reserveVT.conf
# Use sysusers to create gdm system user
Source11:       gdm.sysusers
# PAM configuration files for SLE15 and older
Source12:       gdm-sle.pamd
Source13:       gdm-autologin-sle.pamd
Source14:       gdm-fingerprint-sle.pamd
Source15:       gdm-smartcard-sle.pamd
# Configuration for pulseaudio
Source20:       default.pa
# WARNING: do not remove/significantly change patch0 without updating the relevant patch in accountsservice too
# PATCH-FIX-OPENSUSE gdm-s390-not-require-g-s-d_wacom.patch bsc#1129412 yfjiang@suse.com -- Remove the runtime requirement of g-s-d Wacom plugin
Patch0:         gdm-s390-not-require-g-s-d_wacom.patch
# PATCH-FIX-OPENSUSE  gdm-sysconfig-settings.patch bnc432360 bsc#919723 hpj@novell.com -- Read autologin options from /etc/sysconfig/displaymanager; note that accountsservice has a similar patch (accountsservice-sysconfig.patch)
Patch1:         gdm-sysconfig-settings.patch
# PATCH-FIX-OPENSUSE gdm-suse-xsession.patch vuntz@novell.com -- Use the /etc/X11/xdm/* scripts
Patch2:         gdm-suse-xsession.patch
# PATCH-FIX-OPENSUSE gdm-xauthlocalhostname.patch bnc#538064 vuntz@novell.com -- Set XAUTHLOCALHOSTNAME to current hostname when we authenticate, for local logins, to avoid issues in the session in case the hostname changes later one. See comment 24 in the bug.
Patch4:         gdm-xauthlocalhostname.patch
# PATCH-FIX-OPENSUSE gdm-switch-to-tty1.patch bsc#1113700 xwang@suse.com -- switch to tty1 when stopping gdm service
Patch5:         gdm-switch-to-tty1.patch
# PATCH-FIX-OPENSUSE gdm-initial-setup-hardening.patch boo#1140851, glgo#GNOME/gnome-initial-setup#76 fezhang@suse.com -- Prevent gnome-initial-setup running if any regular user has perviously logged into the system
Patch6:         gdm-initial-setup-hardening.patch
# PATCH-FIX-UPSTREAM gdm-settings-utils_rename-variable.patch -- Rename variable to fix build with gcc 15
Patch7:         gdm-settings-utils_rename-variable.patch
# PATCH-FIX-UPSTREAM gdm-fix-wrong-path-gdm-config.patch bsc#1232669, glgo#GNOME/gdm!282 alynx.zhou@suse.com -- Add missing slash when gdm-config building dconf database path
Patch8:         gdm-fix-wrong-path-gdm-config.patch

### NOTE: Keep please SLE-only patches at bottom (starting on 1000).
# PATCH-FIX-SLE gdm-disable-gnome-initial-setup.patch bnc#1067976 qzhao@suse.com -- Disable gnome-initial-setup runs before gdm, g-i-s will only serve for CJK people to choose the input-method after login.
Patch1000:      gdm-disable-gnome-initial-setup.patch

BuildRequires:  /usr/bin/dbus-run-session
BuildRequires:  check-devel
# dconf and gnome-session-core are needed for directory ownership
BuildRequires:  dconf
BuildRequires:  fdupes
BuildRequires:  gnome-session-core
BuildRequires:  itstool
BuildRequires:  meson >= 0.57
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  tcpd-devel
BuildRequires:  xorg-x11-server
BuildRequires:  xorg-x11-server-extra
BuildRequires:  pkgconfig(accountsservice) >= 0.6.35
BuildRequires:  pkgconfig(audit)
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(gio-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.56.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.12
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 2.91.1
BuildRequires:  pkgconfig(gudev-1.0) >= 232
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libkeyutils)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(ply-boot-client)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
Requires:       %{_bindir}/dbus-run-session
Requires:       %{name}-branding = %{version}
Requires:       gdmflexiserver
Requires:       gnome-session-core
Requires:       gnome-settings-daemon
Requires:       gnome-shell
# xdm package ships systemd display-manager service and other common scripts
# between display managers (bsc#1084655)
Requires:       (gdm-xdm-integration or gdm-systemd)
%if !0%{?is_opensuse}
Suggests:       gdm-systemd
%else
Suggests:       gdm-xdm-integration
%endif
Requires(post): dconf
Requires(pre):  group(video)
Recommends:     iso-codes
# accessibility
Recommends:     orca
# smartcard login
Recommends:     pam_pkcs11
DocDir:         %{_defaultdocdir}
%ifnarch s390 s390x
BuildRequires:  pkgconfig(xorg-server)
%endif
%sysusers_requires

%description
The GNOME Display Manager is a system service that is responsible for
providing graphical log-ins and managing local and remote displays.

%package -n libgdm1
Summary:        Client Library for Communicating with GDM Greeter Server
Group:          System/Libraries
Requires:       %{name}-schema
Recommends:     gdm

%description -n libgdm1
The GNOME Display Manager is a system service that is responsible for
providing graphical log-ins and managing local and remote displays.

%package -n typelib-1_0-Gdm-1_0
Summary:        Introspection bindings for gdm
Group:          System/Libraries

%description -n typelib-1_0-Gdm-1_0
The GNOME Display Manager is a system service that is responsible for
providing graphical log-ins and managing local and remote displays.

This package provides the GObject Introspection bindings for
communicating with the GDM greeter server.

%package schema
Summary:        Config schema for GDM
Group:          System/Libraries
BuildArch:      noarch

%description schema
The GNOME Display Manager is a system service that is responsible for
providing graphical log-ins and managing local and remote displays.

%package devel
Summary:        Libraries for GDM -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libgdm1 = %{version}
Requires:       typelib-1_0-Gdm-1_0 = %{version}

%description devel
The GNOME Display Manager is a system service that is responsible for
providing graphical log-ins and managing local and remote displays.

%package branding-upstream
Summary:        The GNOME Display Manager -- Upstream default configuration
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: Provide one file:
#BRAND: /etc/gdm/custom.conf
#BRAND:   Default configuration of gdm

%description branding-upstream
The GNOME Display Manager is a system service that is responsible for
providing graphical log-ins and managing local and remote displays.

This package provides the upstream default configuration for gdm.

%package xdm-integration
Summary:        GDM integration into the xdm wrapper script
Group:          System/GUI/GNOME
Requires:       gdm
Requires:       xdm
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description xdm-integration
GDM's XDM wrapper integration
By default openSUSE uses xdm which enables the DM based on sysconfig.

%package systemd
Summary:        Systemd gdm.service file
Group:          System/GUI/GNOME
Requires:       gdm
# Upgrade xdm first if installed - to run systemd DM migration
Requires(pre):  (xdm >= 1.1.17 if xdm)
BuildArch:      noarch

%description systemd
GDM's systemd service file.
By default openSUSE uses xdm which enables the DM based on sysconfig.
This package is only needed if the system administrator wishes to use
'systemctl' instead of openSUSE's default 'update-alternatives' method.

%package -n gdmflexiserver
Summary:        Compatibility Wrapper for Display Managers
Group:          System/GUI/GNOME
Suggests:       gdm
BuildArch:      noarch

%description -n gdmflexiserver
The GDMFlexiServer tool interacts with the display manager to
enable fast user switching. This package contains a wrapper that
selects the correct Gdmflexiserver implementation, based on the
running display manager.

%lang_package

%prep
%autosetup -N
### NON-SLE patches start from 0 to 999
%autopatch -p1 -m 1 -M 999

%ifarch s390 s390x
%patch -P 0 -p1
%endif

### SLE and Leap only patches start at 1000
%if !0%{?is_opensuse} || 0%{?suse_version} <= 1600
## Use this when there's no need to skip patches.
%autopatch -p1 -m 1000
%endif

%build
%meson \
        --libexecdir=%{_libexecdir}/gdm \
        -Dat-spi-registryd-dir=%{_libexecdir}/at-spi \
        -Dgdm-xsession=true \
        -Dgnome-settings-daemon-dir=%{_libexecdir}/gnome-settings-daemon-3.0 \
        -Dinitial-vt=7 \
        -Dipv6=true \
        -Dpam-mod-dir=%{_pam_moduledir} \
        -Ddbus-sys=%{_datadir}/dbus-1/system.d \
	-Ddistro=generic \
        -Dplymouth=enabled \
        -Drun-dir=/run/gdm \
%if %{enable_split_authentication}
        -Dsplit-authentication=true \
%else
        -Dsplit-authentication=false \
%endif
        -Dudev-dir=%{_udevrulesdir} \
        -Dwayland-support=true \
%if !0%{?is_opensuse}
        -Dx11-support=false \
%endif
        %nil
%meson_build
%sysusers_generate_pre %{SOURCE11} gdm gdm.conf

%install
%meson_install
## Install PAM files.
mkdir -p %{buildroot}%{_pam_vendordir}
# Pam config for the greeter session
cp %{SOURCE3} %{buildroot}%{_pam_vendordir}/gdm-launch-environment
%if 0%{?suse_version} >= 1550
# Generic pam config
cp %{SOURCE1} %{buildroot}%{_pam_vendordir}/gdm
# Pam config for autologin
cp %{SOURCE2} %{buildroot}%{_pam_vendordir}/gdm-autologin
%if %{enable_split_authentication}
# Pam config for fingerprint authentication
cp %{SOURCE4} %{buildroot}%{_pam_vendordir}/gdm-fingerprint
# Pam config for smartcard authentication
cp %{SOURCE5} %{buildroot}%{_pam_vendordir}/gdm-smartcard
%endif
%else
# Generic pam config
cp %{SOURCE12} %{buildroot}%{_pam_vendordir}/gdm
# Pam config for autologin
cp %{SOURCE13} %{buildroot}%{_pam_vendordir}/gdm-autologin
%if %{enable_split_authentication}
# Pam config for fingerprint authentication
cp %{SOURCE14} %{buildroot}%{_pam_vendordir}/gdm-fingerprint
# Pam config for smartcard authentication
cp %{SOURCE15} %{buildroot}%{_pam_vendordir}/gdm-smartcard
%endif
%endif
# The default gdm pam configuration is the one to be used as pam-password too
ln -s gdm %{buildroot}%{_pam_vendordir}/gdm-password
## Install other files
# Install PostLogin script.
mv %{buildroot}%{_sysconfdir}/gdm/PostLogin/Default.sample %{buildroot}%{_sysconfdir}/gdm/PostLogin/Default
# Move gdmflexiserver to libexecdir and replace it with the compatibility wrapper
mv %{buildroot}%{_bindir}/gdmflexiserver %{buildroot}%{_libexecdir}/gdm/gdmflexiserver
install -m 755 %{SOURCE6} %{buildroot}%{_bindir}/gdmflexiserver
sed -e 's-@LIBEXECDIR@-%{_libexecdir}-g' -i %{buildroot}%{_bindir}/gdmflexiserver
#Install /etc/xinit.d/xdm integration script
install -D -m 644 %{SOURCE7} %{buildroot}%{_prefix}/lib/X11/displaymanagers/gdm
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-displaymanager
ln -s %{_sysconfdir}/alternatives/default-displaymanager %{buildroot}%{_prefix}/lib/X11/displaymanagers/default-displaymanager
# Install other files
mkdir -p %{buildroot}/run/gdm
mkdir -p %{buildroot}%{_bindir}
ln -s ../sbin/gdm %{buildroot}%{_bindir}/gdm

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 644 %{SOURCE9} %{buildroot}%{_tmpfilesdir}/gdm.conf
%if !0%{?is_opensuse}
sed -e '#/var/lib/gdm/\.pulse#d' -i %{buildroot}%{_tmpfilesdir}/gdm.conf
%endif

mkdir -p %{buildroot}%{_prefix}/lib/systemd/logind.conf.d
install -m 644 %{SOURCE10} %{buildroot}%{_prefix}/lib/systemd/logind.conf.d/reserveVT.conf

mkdir -p %{buildroot}%{_sysusersdir}
install -m 644 %{SOURCE11} %{buildroot}%{_sysusersdir}/gdm.conf

%if 0%{?is_opensuse}
install -D -m 644 %{SOURCE20} %{buildroot}%{_prefix}/share/factory/var/lib/gdm/.pulse/default.pa
%endif

%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}%{_datadir}/help

%check
%meson_test

%pre -f gdm.pre

%post
%tmpfiles_create gdm.conf

%post xdm-integration
%{_sbindir}/update-alternatives --install %{_prefix}/lib/X11/displaymanagers/default-displaymanager \
  default-displaymanager %{_prefix}/lib/X11/displaymanagers/gdm 25

%posttrans
# Create dconf database for gdm, to lockdown the gdm session
dconf update

%postun xdm-integration
[ -f %{_prefix}/lib/X11/displaymanagers/gdm ] || %{_sbindir}/update-alternatives \
  --remove default-displaymanager %{_prefix}/lib/X11/displaymanagers/gdm

%pre systemd
%service_add_pre gdm.service

%post systemd
%service_add_post gdm.service

%preun systemd
%service_del_preun gdm.service

%postun systemd
%dnl do not restart gdm.service, as we might lose the graphical session we're in
%service_del_postun_without_restart gdm.service

%posttrans systemd
%dnl migrate a system that still uses xdm abstraction as display manager to gdm
%dnl part of https://en.opensuse.org/openSUSE:DisplayManagerRework
if [ "$(systemctl is-enabled display-manager-legacy)" = "enabled" ]; then
  # display-manager is currently 'legacy mode' - if migration has already occured
  # the above command would return 'disabled'
  if [ -x /usr/sbin/update-alternatives ]; then
    if [ "$(update-alternatives  --query default-displaymanager | awk '/Value:/ {print $2}')" = "/usr/lib/X11/displaymanagers/gdm" ]; then
      # the display-manager started by xdm is currently gdm - let's switch to the native service
      # this only force-enables gdm whenever xdm was enabled AND it was uses as wrapper to start gdm
      systemctl enable --force gdm.service
    fi
  fi
fi

%ldconfig_scriptlets -n libgdm1

%files
%license COPYING
%doc AUTHORS NEWS README.md
%doc %{_datadir}/help/C/%{name}/
%dir %config %{_sysconfdir}/gdm
%config %{_sysconfdir}/gdm/[IPXl]*
%{_sbindir}/gdm
%{_bindir}/gdm
%{_bindir}/gdm-config
%dir %{_datadir}/dconf
%dir %{_datadir}/dconf/profile
%{_datadir}/dconf/profile/gdm
%if 0%{?is_opensuse}
%dir %{_datadir}/factory/var
%dir %{_datadir}/factory/var/lib
%{_datadir}/factory/var/lib/gdm
%endif
%{_datadir}/gdm/
%{_datadir}/gnome-session/sessions/gnome-login.session
%{_pam_moduledir}/pam_gdm.so
%dir %{_libexecdir}/gdm
%{_libexecdir}/gdm/gdm-*
%{_libexecdir}/gdm/gdmflexiserver
%ghost %attr(750,gdm,gdm) %dir %{_localstatedir}/lib/gdm
%if 0%{?is_opensuse}
%attr(0700, gdm, gdm) %ghost %dir %{_localstatedir}/lib/gdm/.pulse
%attr(0600, gdm, gdm) %ghost %{_localstatedir}/lib/gdm/.pulse/default.pa
%endif
%ghost %attr(711,root,gdm) %dir %{_localstatedir}/log/gdm
%ghost %attr(1755,root,root) /var/cache/gdm
%ghost %attr(711,root,gdm) %dir /run/gdm
%_config_norepl %{_pam_vendordir}/gdm
%_config_norepl %{_pam_vendordir}/gdm-autologin
%if %{enable_split_authentication}
%_config_norepl %{_pam_vendordir}/gdm-fingerprint
%_config_norepl %{_pam_vendordir}/gdm-smartcard
%endif
%_config_norepl %{_pam_vendordir}/gdm-password
%_config_norepl %{_pam_vendordir}/gdm-launch-environment
%{_datadir}/dbus-1/system.d/gdm.conf
%if 0%{?is_opensuse}
%{_udevrulesdir}/61-gdm.rules
%endif
%{_datadir}/polkit-1/rules.d/20-gdm.rules
%{_tmpfilesdir}/gdm.conf
%{_sysusersdir}/gdm.conf
%dir %{_prefix}/lib/systemd/logind.conf.d
%{_prefix}/lib/systemd/logind.conf.d/reserveVT.conf
%dir %{_userunitdir}/gnome-session@gnome-login.target.d
%{_userunitdir}/gnome-session@gnome-login.target.d/session.conf

%files xdm-integration
# /etc/xinit.d/xdm integration
%dir %{_prefix}/lib/X11/displaymanagers
%{_prefix}/lib/X11/displaymanagers/default-displaymanager
%{_prefix}/lib/X11/displaymanagers/gdm
%ghost %{_sysconfdir}/alternatives/default-displaymanager

%files -n libgdm1
%{_libdir}/libgdm.so.*

%files -n typelib-1_0-Gdm-1_0
%{_libdir}/girepository-1.0/Gdm-1.0.typelib

%files schema
%{_datadir}/glib-2.0/schemas/org.gnome.login-screen.gschema.xml

%files devel
%{_includedir}/gdm/
%{_libdir}/libgdm.so
%{_libdir}/pkgconfig/gdm.pc
%{_libdir}/pkgconfig/gdm-pam-extensions.pc
%{_datadir}/gir-1.0/Gdm-1.0.gir

%files branding-upstream
%config(noreplace) %{_sysconfdir}/gdm/custom.conf

%files systemd
%{_unitdir}/gdm.service

%files -n gdmflexiserver
%{_bindir}/gdmflexiserver

%files lang -f %{name}.lang

%changelog
* Wed Jun 18 2025 Valentin Lefebvre <valentin.lefebvre@suse.com>
- pam.d: removes pam_env from auth stack for security reason
  [bsc#1243226, CVE-2025-6018]
* Fri May 30 2025 Alynx Zhou <alynx.zhou@suse.com>
- Add gdm-fix-wrong-path-gdm-config.patch: Add missing slash when
  gdm-config building dconf database path (bsc#1232669).
* Fri May 30 2025 Alynx Zhou <alynx.zhou@suse.com>
- Add -Ddistro=generic to make gdm-config work (bsc#1232669).
* Sun May  4 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Drop obsolete gnome-common BuildRequires. Add itstool
  BuildRequires.
* Mon Apr 14 2025 Joan Torres <joan.torres@suse.com>
- SLES16 won't ship pulseaudio-gdm-hooks so remove the last missing
  bits.
* Mon Apr  7 2025 Joan Torres <joan.torres@suse.com>
- Disable X11 support on SLE:
  * SLFO will only support Wayland
  * This is required to avoid a fallback to X11 sessions which
    makes GDM crash
  * With this change gdm-exclude-61-gdm-rules-file.patch is
    not needed anymore
* Thu Mar 27 2025 Bjørn Lie <bjorn.lie@gmail.com>
- No longer rm -vrf
  %%{buildroot}%%{_datadir}/polkit-1/rules.d/20-gdm.rules, now that
  boo#1239719 is resolved.
* Wed Mar 26 2025 Callum Farmer <gmbr3@opensuse.org>
- Update systemd xdm migration
  * Change display-manager to display-manager-legacy
  * Actually detect gdm instead of xdm
  * Upgrade xdm first if installed to run the systemd migration
* Fri Mar 21 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Rebase/fix gdm-switch-to-tty1.patch to fix build against gcc 15.
* Thu Mar 20 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Add gdm-settings-utils_rename-variable.patch: Rename variable to
  fix build with gcc 15
  (https://gitlab.gnome.org/GNOME/gdm/-/merge_requests/273).
* Tue Mar 18 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Add systemd scriptlets to gdm-systemd packages. On postun, ensure
  to NOT restart gdm, as this would cost the graphical session.
- Fix rpmlint error: zero-perms-ghost. Give /var/cache/gdm some
  default attributes, matching the attributes in
  tmpfiles.d/gdm.conf.
* Tue Mar 18 2025 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Install gdm-systemd by default on SLE (jsc#PED-1904).
* Mon Mar 17 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Allow changing global network settings
  + Updated translations.
- Use ldconfig_scriptlets macro for post(un) handling.
- Drop obsolete update-desktop-files BuildRequires.
- Drop old and no longer relevant gdm2, gnome-applets-gdm and
  pulseaudio-gdm-hooks Provides and Obsoletes.
- Build gdm-xdm-integration as noarch.
* Mon Mar 17 2025 Michael Gorse <mgorse@suse.com>
- Fix build on SLE 16: remove sle_version in another place, and
  Patch7 has been removed.
* Fri Mar 14 2025 Michael Gorse <mgorse@suse.com>
- Drop use of sle_version in favor of is_opensuse and suse_version.
  Sle_version is no longer used in SLE 16.
* Thu Mar 13 2025 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-exclude-61-gdm-rules-file.patch: Exclude 61-gdm.rules file
  when X is not supported (jsc#PED-1904).
- Drop upstream patches:
  + gdm-xvnc-start-session-failed.patch:
* Fri Mar  7 2025 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Xorg server is not supported by SLE16:
  + Remove gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
  + Remove gdm-restart-session-when-X-server-restart.patch
  + Update X11-displaymanager-gdm
* Thu Feb  6 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.beta:
  + Don't require Xwayland if wayland-only
  + Fix pam_syslog detection
  + Fix Solaris build
  + Fix udev rules for disabling wayland
  + Add 'banner-message-path' and '-source' settings
- Rebase gdm-xauthlocalhostname.patch.
* Wed Nov 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add migration code from 'xdm' display-manager wrapper to native
  gdm systemd service.
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + Fix X11 support.
* Thu Sep 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Split the xdm-wrapper parts into gdm-xdm-integration. Require
  this new package or gdm-systemd by gdm (suggesting the
  xdm-integration for now).
* Wed Sep 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Make X11 support optional
  + Support logind secure attention key
  + Drop gdm-screenshot
  + Don't hardcode g-r-d in dbus policy
  + Fix numeric local address resolution
  + Docs updates
  + Updated translations.
- Changes from version 47.alpha:
  + Support for gnome-remote-desktop persistent sessions
  + Misc changes
  + Updated translations.
- Drop pkgconfig(libcanberra-gtk3) BuildRequires: No longer needed,
  nor used.
* Thu Aug 15 2024 Alynx Zhou <alynx.zhou@suse.com>
- Add pam_pkcs11 as Recommends for smartcard login (bsc#1223580).
* Mon Aug 12 2024 Michael Gorse <mgorse@suse.com>
- Fix applying patches when sle_version is defined
* Fri Aug  9 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop gdm-default-wm.patch: patch seems obsolete. The selection of
  default window manager happens by means of update-alternatives
  now.
* Tue Jul 30 2024 Michael Gorse <mgorse@suse.com>
- Rebase gdm-restart-session-when-X-server-restart.patch.
* Wed Jun 19 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gdm-sysconfig-settings.patch: work with SELinux policy
  (bsc#1222978).
* Mon Jun  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Block suspend when remote displays are active.
  + Support S0ix suspend when deciding if nvidia should use
    wayland.
  + Misc fixes.
  + Updated translations.
- Rebase gdm-initial-setup-hardening.patch.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + PAM improvements.
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Support for killing conflicting sessions at login time.
  + XDMCP fix.
  + Use wayland by default on certain server chips.
  + Fix pam extension size computation.
  + Introspection fix.
  + Fix for homed users.
  + Updated translations.
- Rebase gdm-default-wm.patch and
  gdm-xvnc-start-session-failed.patch.
* Mon Mar  4 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Rebase gdm-sysconfig-settings.patch: to fix build with GCC 14.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Support remote login from gnome-remote-desktop (and hopefuly
    nicedcv in the future).
  + Support new JSON pam extension.
  + Fix build with user-display-server=false.
  + Minor clean ups.
  + Move private D-Bus sockets to private directory.
  + Build goo fixes.
  + Warning fixes.
  + Updated translations.
- Rebase gdm-default-wm.patch.
- Add pkgconfig(json-glib-1.0) BuildRequires: new dependency.
- Convert to source service for easier updating.
* Mon Mar  4 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gdm-xvnc-start-session-failed.patch: Following the upstream
  final solution(bsc#1219205 glgo#GNOME/gdm#909).
* Thu Feb 22 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-xvnc-start-session-failed.patch: None seat0 session runs
  without running launcher(bsc#1219205 glgo#GNOME/gdm#909).
* Wed Feb 21 2024 Alynx Zhou <alynx.zhou@suse.com>
- Drop gdm-disable-wayland-on-mgag200-chipsets.patch: fixed
  upstream since version 43.0.
* Tue Jan 23 2024 Yifan Jiang <yfjiang@suse.com>
- Make Patch0 only applies on s390 and s390x.
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Thu Nov  2 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Rebase patches for SLE-15-SP6 (bsc#216595):
  + Rebase gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
  + Rebase gdm-disable-gnome-initial-setup.patch
  + Rebase gdm-restart-session-when-X-server-restart.patch
* Mon Oct  2 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Explicitly buildrequire /usr/bin/dbus-run-session: the
  dbus package is being restructured to be usable with dbus-broker
  and so far we just relied on implicit dependencies bringing this
  in. Meson checks for it, so it is correct to BR it though.
* Thu Sep 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0.1:
  + Fix for the crasher fix.
- Changes from version 45.0:
  + Crasher fix.
  + Updated translations.
- Rebase gdm-xauthlocalhostname.patch with quilt.
* Wed Aug 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + A ton of small code clean ups and small leak fixes.
  + Set gnome-initial-setup dconf profile.
  + Honor settings configured with a template in AccountsService.
  + Crash fix from stray udev events.
  + VT handling fixes.
  + Work better in presence of simpledrm.
  + wayland multi-seat support.
- Rebase patches with quilt.
- Drop upstream patches:
  + gdm-fix-btmp-record-with-seat.patch
  + gdm-disable-wayland-on-aspeed-chipsets.patch
* Mon Aug 14 2023 Yifan Jiang <yfjiang@suse.com>
- Do not use %%autopatch to build on SLE where rpm version is not
  ready for the macro.
* Fri Jun 30 2023 Fabian Vogt <fvogt@suse.com>
- Merge pulseaudio-gdm-hooks into the gdm package. This was previously
  part of pulseaudio.spec, which was fairly complex (dir ownership,
  separate tmpfiles, dependencies) and it also caused pulseaudio.spec
  to runtime depend on gdm. Avoid all of that by just adding it here:
  + Add default.pa
  + Add entries to gdm.tmpfiles
* Mon Jun  5 2023 Alynx Zhou <alynx.zhou@suse.com>
- Add gdm-fix-btmp-record-with-seat.patch: When writing btmp record
  display name is needed, but user don't have a display before
  logging in, this patch uses seat instead which is also better for
  Wayland (bsc#1211825).
* Fri May  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Fix blown assertion log spew.
  + Updated translations.
* Tue Mar 28 2023 Thorsten Kukuk <kukuk@suse.com>
- Create two set of pam configuration files:
  + *-sle.pamd are for SLES15 and older
  + add postlogin-* includes to the others as required by openSUSEs
    PAM config policy
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Updated translations.
* Thu Mar  9 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 44.rc:
  + Lots of code clean ups.
  + Fix detection of virt on efi setups.
  + Fix btmp accounting on failed logins.
  + Ensure pam_close_session is called even if worker is killed.
  + Updated translations.
- Drop gdm-switch-user-tty7.patch: fixed upstream.
- Refresh patches with Quilt.
- Rebase gdm-xauthlocalhostname.patch due to code clean up commit:
  88d79fe24cda8623a4b460c0aa9628178c26f745.
* Wed Jan 18 2023 Yifan Jiang <yfjiang@suse.com>
- Update gdm-disable-gnome-initial-setup.patch: Refactoring to
  disable it on SLE runtime, so with the same executable it is
  still possible to run on Leap (jsc#PED-1719).
* Wed Jan  4 2023 Alynx Zhou <alynx.zhou@suse.com>
- Update gdm-smartcard.pamd: Move pam_nologin.so under pam_pkcs11.so
  to make it work with pam_pkcs11's auto file username.
* Fri Dec  2 2022 Alynx Zhou <alynx.zhou@suse.com>
- Update gdm-fingerprint.pamd and gdm-smartcard.pamd: Before this
  they do not really support fingerprint and smartcard, just put
  correct configuration to make them work (bsc#1205664).
- Enable split authentication because we have correct
  gdm-fingerprint.pamd and gdm-smartcard.pamd.
* Mon Oct 31 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gdm-sysconfig-settings.patch: Fix gdm doesn't start
  if /etc/sysconfig/displaymanager is missing (bsc#1204578).
* Wed Oct  5 2022 Callum Farmer <gmbr3@opensuse.org>
- Move dbus system.d conf file to /usr (bsc#1204052)
* Tue Sep 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Drop vestigial code.
  + Fixes in GPU detection.
  + Use _GNU_SOURCE again to avoid compile warning.
  + Updated translations.
- Drop patches fixed upstream:
  + gdm-Fix-type-of-signal-connection-id.patch
  + gdm-Stop-listening-to-udev-events.patch
- Rebase patches with quilt.
* Tue Aug  2 2022 Yifan Jiang <yfjiang@suse.com>
- Fix specfile: Adapt macros %%_pam_moduledir (boo#1191033).
* Fri Jul  8 2022 Alynx Zhou <alynx.zhou@suse.com>
- Add gdm-disable-wayland-on-aspeed-chipsets.patch: Those chips do
  not have fast blending and Wayland performance is bad on them, so
  disable Wayland on aspeed chipsets (bsc#1200323).
* Tue Apr 26 2022 Frederic Crozat <fcrozat@suse.com>
- Ensure /run/gdm is created by tmpfiles.
* Fri Apr  1 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-Fix-type-of-signal-connection-id.patch: backport upstream
  commit f0f527ff (bsc#1197521).
- Add gdm-Stop-listening-to-udev-events.patch: backport upstream
  commit 307c683f (bsc#1197521).
* Mon Mar 21 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 42.0:
  + Improvements to work better on NVidia cards.
  + Look in DATADIR for launching environment data files.
  + PAM updates on exherbo.
  + Updated translations.
- Add pkgconfig(gudev-1.0), with minimal version of 232, as a new
  build requirement.
- Add explicit update-alternatives to post(un) requirements to
  avoid rare unexpected behaviors due to package order of
  installation.
- Replace systemdsystemunitdir with _unitdir macro. There's no need
  to manually define it anymore since systemd-rpm-macros already
  provide it.
* Wed Mar 16 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-restart-session-when-X-server-restart.patch:
  Avoiding the blank screen when X server restarts with
  GDM_DISABLE_USER_DISPLAY_SERVER=1 (bsc#1196974).
* Wed Feb 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Use _pam_vendordir instead of _distconfdir/pam.d (boo#1195996).
  AS this means /etc/pam.d on SLE15, we mark those files as
  %%config(noreplace).
* Wed Jan 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.3:
  + Juggle Xorg's -listen/-nolisten command line change better.
  + Fix session type selection.
  + Fix crash.
  + Drop vestigial gdm-pin service.
  + XDMCP fixes.
  + Wayland nvidia udev updates.
  + Updated translations.
- Rebase gdm-disable-wayland-on-mgag200-chipsets.patch.
- Drop gdm-daemon-Infer-session-type-from-desktop-file.patch and
  gdm-restart-greeter-session-after-crash.patch: fixed upstream.
* Thu Dec 30 2021 Simon Vogl <simon.vogl@gmx.net>
- Move
  %%{_datadir}/glib-2.0/schemas/org.gnome.login-screen.gschema.xml
  from main package to new gdm-schema split package and make
  libgdm1 depend on the new gdm-schema split package. Currently,
  the gdm-schema is required for gnome-shell to work, but
  gnome-shell only depends on libgdm1 and not on gdm as a whole,
  causing a crash of gnome-shell if the gdm main package is not
  installed. By moving the gdm-schema to it's own split package and
  making libgdm1 actually require it, the crash can be prevented.
  Fixes boo#1194183.
* Wed Dec  8 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-restart-greeter-session-after-crash.patch: When active vt
  is gdm initial vt, restart greeter session. Avoiding the blank
  screen when greeter session crashed
  (bsc#1190230 glgo#GNOME/gdm#735).
* Tue Nov 23 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch:
  With GDM_DISABLE_USER_DISPLAY_SERVER=1 environment variable, make
  X server logging to /var/log/Xorg.*.log and journal log
  (bsc#1192177).
* Tue Oct 19 2021 Martin Wilck <mwilck@suse.com>
- Add gdm-daemon-Infer-session-type-from-desktop-file.patch
  (bsc#1191809, bsc#1191248)
* Tue Oct 12 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Rebase gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
  (bsc#1191014).
* Tue Sep 28 2021 Yifan Jiang <yfjiang@suse.com>
- Rebase gdm-disable-gnome-initial-setup.patch.
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Sep  7 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch:
  Support to start X under root instead of regular user.
  (bnc#1188912 jsc#SLE-17880).
- Update X11-displaymanager-gdm file.
* Mon Sep  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc:
  + Fix fallback to Xorg at login screen.
  + Fix SessionType in AccountService user config.
  + Reuse VT on log out.
  + Updated translations.
* Mon Aug 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.alpha:
  + Allow user session to be Wayland even when login screen is
    Xorg.
  + Allow wayland user sessions for single GPU vendor nvidia
    machines.
  + Updated translations.
* Wed Aug 11 2021 Yifan Jiang <yfjiang@suse.com>
- Rebase patches:
  + gdm-s390-not-require-g-s-d_wacom.patch
  + gdm-disable-gnome-initial-setup.patch
* Tue Aug  3 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Rebased gdm-default-wm.patch.
* Fri Jul 30 2021 Yifan Jiang <yfjiang@suse.com>
- Drop patches fixed upstream on SLE and Leap 15.4:
  + gdm-enable-Wayland-on-Cirrus.patch
  + gdm-Remove-deprecated-StandardOutput-syslog.patch
  + gdm-fix-crash-when-using-Xvfb.patch
  + gdm-display-Exit-with-failure-if-loading-existing-users-fails.patch
* Sat Jul 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.1:
  + Better support for unlocking gnome-keyring with disk password
  + Better support for flatpak
  + Misc auth fixes
  + Improved error output in gdm-runtime-config
  + Sort session list on login screen
  + Support Session and SessionType properties from accountsservice
  + Updated translations.
- Rebase gdm-xauthlocalhostname.patch.
- Disable gdm-default-wm.patch, needs reworking.
* Mon Jul  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Add now working CONFIG parameter to sysusers generator
* Fri Apr 23 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-Remove-deprecated-StandardOutput-syslog.patch: Remove
  deprecated StandardOutput=syslog in gdm.service file
  (bsc#1185146, glgo#GNOME/gdm!623).
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + 100%% CPU fix.
  + Updated translations.
* Wed Mar 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Fingerprint auth fixes.
  + Fix timeout handling for graphics bringup.
  + Updated translations.
* Tue Mar  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + xinit script improvements.
  + Build goo fixes.
  + Support systems that boot before the graphics subsystem fully
    loads.
  + Don't overwrite PATH set by user.
  + Generalize gdm-disable-wayland into new gdm-runtime-config
    tool.
  + Fail hard if accountsservice fails.
  + PAM integration improvements.
  + Leak fixes.
  + Stop using deprecated systemd functions.
- Changes from version 3.38.2.1:
  + Address autologin unlock bug issue (CVE-2020-27837).
  + Updated translations.
- Rebase gdm-disable-wayland-on-mgag200-chipsets.patch.
- Drop gdm-UsrEtc.patch: merged upstream.
* Fri Jan 29 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fixup gdm.sysyers: gecos field needs to be quoted for multi-word
  value.
* Thu Jan 21 2021 Thorsten Kukuk <kukuk@suse.com>
- Use sysusers config file to generate gdm user
* Mon Jan 18 2021 Alynx Zhou <alynx.zhou@suse.com>
- Add gdm-fix-crash-when-using-Xvfb.patch: For some reason gdm
  fails to get display and does not set it to NULL when using
  with Xvfb, and it leads into a crash, this patch sets display
  to NULL by default. (bsc#1178292, glgo#GNOME/gdm!118)
* Mon Jan  4 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch:
  Fix switching user issue(bsc#1179968, bsc#1174533).
* Fri Nov 13 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gdm-display-Exit-with-failure-if-loading-existing-users-fails.patch:
  Exit with failure if loading existing users fails
  (bsc#1178150 glgo#GNOME/gdm!117 CVE-2020-16125).
- Update gdm-disable-gnome-initial-setup.patch
* Wed Nov  4 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.38.2:
  + Fix localization bug to prevented translated messages from
    showing up.
  + Deal more appropriately with broken accountsservice.
* Tue Oct 20 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update gdm-suse-xsession.patch: Handle the fact that xdm moved
  its files from /etc to /usr/etc (boo#1177918).
* Thu Oct 15 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Fix bug leading to users /etc/gdm/custom.conf getting
    overwritten on nvidia systems.
  + Fix typo in comment.
  + Updated translations.
* Tue Oct 13 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Using Xorg.wrap to start X server to solve X server working as root
  in bsc#1075805 (bsc#1175867).
  + Delete gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
  + Update X11-displaymanager-gdm
* Wed Sep 16 2020 Stefan Dirsch <sndirsch@suse.com>
- gdm-UsrEtc.patch
  * needed changes for xdm/xinit/xmodmap move to /usr/etc/X11
    (boo#1173049, boo#1173052, boo#1173053)
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Crasher fix.
  + Systemd unit file improvements.
  + Updated translations.
- Drop gdm-Xsession-inputname.patch: fixed upstream.
* Sun Sep  6 2020 Michael Gorse <mgorse@suse.com>
- Rebase
  gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Updates to systemd integration.
  + Support killling X on login even when wayland support is
    disabled.
- Changes from version 3.37.3:
  + PAM file updates for archlinux.
  + User switching fix.
  + Don't keep login screen running in background on Xorg.
- Changes from version 3.37.1:
  + Switch from autogoo t.o meson
  + Fixes for when GDM isn't started on its configured initial VT.
  + Don't hardcode path to plymouth.
  + keyutils has a .pc file so use it.
  + Enable wayland on cirrus.
  + Chrome remote desktop fix.
  + Always use separate session bus for greeter sessions.
  + Updated translations.
- Add pkgconfig(audit) BuildRequires: new dependency.
- Rebase patches: gdm-disable-wayland-on-mgag200-chipsets.patch,
  gdm-initial-setup-hardening.patch and
  gdm-sysconfig-settings.patch.
- Add gdm-Xsession-inputname.patch:Fix Xsession input file name.
- Port to meson build system:
  + Add meson BuildRequires.
  + Drop autogen.sh source file.
  + Replace configure/make/make_install macros with
    meson/meson_build/meson_install.
* Tue Aug 25 2020 QK ZHU <qkzhu@suse.com>
- Add gdm-enable-Wayland-on-Cirrus.patch: Update udev rules to
  enable Wayland on Cirrus (bsc#1168515, glgo#GNOME/gdm#586).
* Tue Jul 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + User switching fix.
  + Updated translations.
- Disable patch needing rebase:
  + gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
* Tue Jul  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec
* Tue May 26 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch:
  When user session reuses tty7 same as greeter session, gdm
  doesn't bring up the greeter session after switching from other
  tty to tty7 (bsc#1171290).
* Mon May  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Fixes for when GDM isn't started on its configured initial VT.
  + Don't hardcode path to plymouth.
  + keyutils has a .pc file so use it.
  + Chrome remote desktop fix.
  + Always use separate session bus for greeter sessions.
  + This runs dbus-run-session, so the binary needs to be
    available.
  + Updated translations.
- Drop patches fixed upstream:
  + gdm-look-for-session-based-on-pid-first.patch
  + gdm-Use-pkg-config-for-keyutils.patch
- Rebase patches with quilt.
- Add %%{_bindir}/dbus-run-session Requires: New runtime dependency.
  Needed to ensure the dbus-run-session binary is present.
* Sun Apr 26 2020 Yifan Jiang <yfjiang@suse.com>
- Burnish gdm-look-for-session-based-on-pid-first.patch according
  to the upstream change (bsc#1159950, glgo#GNOME/gdm#526).
* Wed Apr 22 2020 Yifan Jiang <yfjiang@suse.com>
- Disable gnome-initial-setup under gdm mode in Leap and SLE
  (jsc#SLE-11856).
* Sat Apr 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add gdm-Use-pkg-config-for-keyutils.patch: configure: Use
  pkg-config to look for keyutils. Following this, replace
  keyutils-devel pkgconfig(libkeyutils) BuildRequires.
- Rebase/refresh patches with quilt.
* Sat Apr 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Enable testsuite: Add check section and run make_build check.
- Tweak bootstrap call, drop superfluous explicit autoreconf call.
* Fri Apr 10 2020 Yifan Jiang <yfjiang@suse.com>
- Add gdm-look-for-session-based-on-pid-first.patch: Look for
  session based on pid first, then fall back to the uid based
  approach (bsc#1159950, glgo#GNOME/gdm#526).
* Wed Mar  4 2020 QK ZHU <qkzhu@suse.com>
- Add gdm-disable-wayland-on-mgag200-chipsets.patch: disable wayland
  on mgag200 chipsets, this patch used to be part of
  gdm-disable-wayland-on-unsupported-chipsets.patch which was dropped,
  however the mgag200 part is still not fixed by upstream. So we should
  keep this part to make sure GNOME works properly on mgag200 chipsets
  (bsc#1162888, glgo#GNOME/mutter#57).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Nov 29 2019 Frederic Crozat <fcrozat@suse.com>
- Refresh SLE patch gdm-s390-not-require-g-s-d_wacom.patch.
* Thu Nov 28 2019 QK ZHU <qkzhu@suse.com>
- Add --enable-systemd-journal for both SLE and Tumbleweed
  (jsc#SLE-10383).
* Tue Nov 19 2019 Xiaoguang Wang <xwang@suse.com>
- Drop gdm-disable-wayland-for-proprietary-nvidia-machines.patch:
  fixed upstream.
* Fri Nov  8 2019 Xiaoguang Wang <xwang@suse.com>
- Add gdm-switch-user-tty7.patch: Switch to tty7 when switch user
  (bsc#1155408 glgo#GNOME#gdm#532).
* Tue Oct  8 2019 Felix Zhang <fezhang@suse.com>
- Add gdm-initial-setup-hardening.patch: Introduce a persistent
  state file to prevent gnome-initial-setup from running if any
  regular users has previously logged into the system, replacing
  the current runtime state file that pervents initial-setup from
  running more than once per boot, so as to reduce the security
  attack surface.
  Make this fix openSUSE only for now as upstream discussion is
  heading another way involving more complicated mechanisms
  (boo#1140851, glgo#GNOME/gnome-initial-setup#76).
- Rebase gdm-disable-gnome-initial-setup.patch.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + De-duplicate sessions on pure Xorg too.
  + Fix fast user switching by assuming the login screen VT is
    always the initial one.
  + Updated translations.
* Wed Sep 18 2019 Xiaoguang Wang <xwang@suse.com>
- Update gdm-switch-to-tty1.patch: switch tty after plymouth
  terminates.
* Wed Sep 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
* Thu Sep  5 2019 luke@ljones.dev
- Update to version 3.33.92:
  + Fix typo in debug message
  + Revert vt changing fix, because it exposes logind bug and it
    wasn't quite right anyway
  + Ensure login screen gets reaped when user switching
  + Translation updates
* Sun Sep  1 2019 Michael Gorse <mgorse@suse.com>
- Update to version 3.33.90:
  + Update for changes to gnome-settings-daemon.
  + initial-setup permissions fix.
  + allow users to set PATH from ~/.config/environment.
  + support systemd user sessions.
  + misc warning fixes.
  + leak fix in libgdm.
  + vt changing fix.
  + drop some deprecations.
  + drop unused icons.
  + Translation updates.
  + Changes in version 3.33.4:
  + Fix session search directories.
  + Kill user sessions when stopping gdm.
  + Add way for sessions to register when they successfully started
  + Translation updates.
- Rebased gdm-xauthlocalhostname.patch and
    gdm-disable-gnome-initial-setup.patch.
- Drop gdm-fails-to-restart-gnome-shell.patch,
  gdm-kill-user-session.patch, and
  gdm-remove-duplicate-sessions.patch: fixed upstream.
- Drop icons and pixmaps from files.
* Fri Aug  2 2019 bjorn.lie@gmail.com
- Update to version 3.32.0+2:
  + Remove erroneous NULL from session search directories.
- Switch to git checkout via source service, upstream is lacking in
  stable releases. In the future we will use a stable tag when
  possible, but when upstream slacks off, we will use a checkout of
  the stable branch.
- Refresh patches with quilt.
* Thu May 23 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Fixup gdm.tmpfiles (boo#1135272).
* Wed May 22 2019 Markus S <kamikazow@opensuse.org>
- Make systemd service file optional instead of outright deleting it.
* Wed May 15 2019 Xiaoguang Wang <xwang@suse.com>
- Update gdm-switch-to-tty1.patch (bsc#1120307)
* Thu May  9 2019 Xiaoguang Wang <xwang@suse.com>
- New solution for auto login problem(bsc#1116011)
  + Drop gdm-revert-commit-39fb4ff.patch
  + Add reserveVT.conf file.
* Sun Apr 28 2019 qzheng <qzheng@suse.com>
- Add gdm-remove-duplicate-sessions.patch: Backport from upstream
  commit 187c8515 and 1795bb31 to remove duplicate sessions once,
  after all sessions have been processed (boo#1131625,
  glgo#GNOME/gdm#473).
* Wed Apr 17 2019 Yifan Jiang <yfjiang@suse.com>
- Add gdm-s390-not-require-g-s-d_wacom.patch: Remove the gnome
  session runtime requirement of g-s-d Wacom plugin because it is
  not build on s390 (bsc#1129412).
* Wed Apr 17 2019 mgorse@suse.com
- Rebase patches (boo#1128589):
  + gdm-sysconfig-settings.patch
  + gdm-default-wm.patch
  + gdm-xauthlocalhostname.patch
  + gdm-kill-user-session.patch
  + gdm-fails-to-restart-gnome-shell.patch
  + gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
- Re-enable gdm-switch-to-tty1.patch
* Wed Apr 17 2019 xwang@suse.com
- Add gdm-revert-commit-39fb4ff.patch: Make auto login successful
  (bsc#1116011).
* Wed Apr 17 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Stable release version bump.
* Wed Apr 17 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.91:
  + Screen lock bypass fix (when timed login is enabled)
    (CVE-2019-3825).
  + PAM file updates.
  + Improved debug logging.
  + Keyboard layout fixes.
  + Display foreach handling.
  + Updated translations.
- Changes from version 3.31.4:
  + DOAP file fixes.
  + Misc code clean ups.
  + Filter out duplicates from session list.
  + Updated translations.
- Disable patches needing rebase:
  + gdm-sysconfig-settings.patch
  + gdm-kill-user-session.patch
  + gdm-default-wm.patch
  + gdm-xauthlocalhostname.patch
  + gdm-switch-to-tty1.patch
  + gdm-fails-to-restart-gnome-shell.patch
  + gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
- Rebase patches with quilt, but sadly not enough, hence the
  massive disabling of patches.
- Drop gdm-ignore-duplicate-desktop-file.patch: Fixed upstream.
- Drop old hack only needed for upgrades from pre SLED 12 and
  openSUSE 10.3.
- Test if we still need to nuke data/61-gdm.rules, aka disable rm.
* Wed Apr 17 2019 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + Screen lock bypass fix (when timed login is enabled)
    (CVE-2019-3825).
  + Updated translations.
- Drop gdm-CVE-2019-3825.patch: Fixed upstream.
* Wed Apr 17 2019 xwang@suse.com
- Add gdm-kill-user-session.patch: Kill all sessions when stopping
  gdm service
  (bsc#1112294 bsc#1120307 bsc#1113245 glgo#GNOME/gdm#400).
- Add gdm-switch-to-tty1.patch: Switch to tty1 when stopping gdm
  service (bsc#1113700).
- Drop gdm-plymouth-vt1.patch: Replaced by gdm-switch-to-tty1.patch
* Wed Apr 17 2019 Felix Zhang <fezhang@suse.com>
- Add gdm-CVE-2019-3825.patch: Fix lock screen bypass when timed
  login is enabled (boo#1124628, glgo#GNOME/gdm#460, CVE-2019-3825)
* Wed Apr 17 2019 qzheng@suse.com
- Add gdm-ignore-duplicate-desktop-file.patch to ignore duplicate
  desktop file with same "Name" value, including symlinks of
  desktop files (bsc#1112834, glgo#GNOME/gdm#437).
- Drop gdm-ignore-duplicate-session.patch, the patch hardcodes
  "default.desktop" while LightDM and SDDM treat symlinks as
  aliases.
* Wed Apr 17 2019 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Fix autologin crash.
  + Unlock keyring again on autologin with newerish systemds.
  + Fix initial-setup.
  + Updated translations.
- Drop patches fixed upstream:
  + gdm-fix-autologin.patch.
  + gdm-fix-initial-setup.patch.
* Wed Apr 17 2019 luc14n0@linuxmail.org
- Add upstream patches:
  + gdm-fix-autologin.patch: as autologin got reworked and broken,
    accessing the proper display variable should fix it.
  + gdm-fix-initial-setup.patch: as the initial-setup related post
    work is done when stopping the greeter and this stop is delayed
    until after the user session is started now, the post work
    needs to be done before the user session is started.
* Wed Apr 17 2019 luc14n0@linuxmail.org
- Re-add still needed 61-gdm.rules removal until glgo#GNOME/gdm#424
  gets fixed.
* Wed Apr 17 2019 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Make udev rule configurable.
  + Follow up fixes dealing with login screen reaping from two
    releases ago.
  + Disable wayland on proprietary nvidia machines for now.
  + Updated translations.
- Drop gdm-make-udev-dir-configurable.patch: Fixed upstream.
* Wed Apr 17 2019 luc14n0@linuxmail.org
- Update to version 3.30.0:
  + No visible changes for the user.
- Drop gdm-ignore-spurios-SeatNew-signal.patch: fixed upstream.
- Add gdm-make-udev-dir-configurable.patch: Make udev directory
  configurable. Patch provided by upstream (glgo#GNOME/gdm!44).
- Rebase gdm-ignore-duplicate-session.patch.
* Wed Apr 17 2019 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Search for sessions in XDG_DATA_DIRS.
  + Blacklist some more wayland unfriendly hardware.
  + Initial setup fix.
  + Flicker fix.
  + Misc bug fixes.
* Wed Apr 17 2019 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + CVE-2018-14424: double free fix.
  + Follow up fixes dealing with login screen reaping form last
    release.
  + Add more debug logging.
  + Updated translations.
- Drop gdm-CVE-2018-14424.patch: Fixed upstream.
- Drop gdm-quit-plymouth-when-xdmcp-is-the-only-allowed-connection.patch:
  Fixed upstream
- Add gdm-ignore-spurios-SeatNew-signal.patch: Fix crashes.
* Wed Apr 17 2019 bjorn.lie@gmail.com
- Update to version 3.28.4:
  + Add missing gdm-disable-wayland binary (fixes VM boots).
  + Disable wayland for certain server cards that mutter can't yet
    handle sufficiently.
- Drop gdm-disable-wayland-on-unsupported-chipsets.patch: Fixed
  upstream.
* Wed Apr 17 2019 luc14n0@linuxmail.org
- Update to version 3.28.3:
  + CVE-2018-14424 - double free fix.
  + Lifecycle fixes to libgdm/GdmClient.
  + Follow up fixes dealing with login screen reaping from last
    release.
  + Allow pam modules to use SIGUSR1.
  + Set PWD for user session.
  + Tell cirrus not to use wayland.
  + Updated translations.
- Drop gdm-CVE-2018-14424.patch: fixed upstream.
- Rebase gdm-disable-wayland-on-unsupported-chipsets.patch applying
  it against data/61-gdm.rules.in instead of data/61-gdm.rules to
  avoid hard coding directories.
* Wed Apr 17 2019 fezhang@suse.com
- Add gdm-CVE-2018-14424.patch: Pass the display object rather than
  the id in the removed signal, fix use-after-free of disposed
  transient displays (CVE-2018-14424, glgo#GNOME#gdm#401,
  boo#1103737).
* Wed Apr 17 2019 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Display wayland on certain server machines.
  + Lifecycle fixes to libgdm/GdmClient.
  + Drop intltool.
  + Build goo clean ups
  + Kill login screen when not in use.
  + Cclean up stale utmp entries.
  + Misc fixes.
  + Updated translations.
- Rebase gdm-disable-wayland-on-unsupported-chipsets.patch.
- Disable
  dm-add-runtime-option-to-disable-starting-X-server-as-u.patch:
  Needs rebase.
- Refresh the following patches with quilt:
  + gdm-default-wm.patch.
  + gdm-fails-to-restart-gnome-shell.patch.
  + gdm-ignore-duplicate-session.patch.
  + gdm-plymouth-vt1.patch.
  + gdm-sysconfig-settings.patch
  + gdm-xauthlocalhostname.patch
* Wed Jan 30 2019 alarrosa@suse.com
- Add gdm.tmpfiles to create directories under /var with
  systemd-tmpfiles in order to support transactional updates.
- Mark directories under /var as %%ghost so they're not created
  during package installation (related to boo#1098063, fate#325524)
* Wed Jan  9 2019 qkzhu@suse.com
- Add gdm-disable-wayland-for-proprietary-nvidia-machines.patch: At
  the moment GLX applications don't work well when the proprietary
  nvidia driver is used with a wayland session. so disable wayland
  on that hardware (glgo#GNOME#gdm!46 bsc#1112578).
* Tue Jul 31 2018 bwiedemann@suse.com
- Update gdm-disable-gnome-initial-setup.patch to avoid build race
  in SLE (boo#1103093)
* Thu Jul 26 2018 dimstar@opensuse.org
- Enable pam_keyinit module (boo#1081947).
* Sat Jun  2 2018 luc14n0@linuxmail.org
- Update to version 3.29.1:
  + Reference counting fixes for GdmClient- ensure plymouth is quit
    properly even when local greeter is disabled.
  + Make sure GDM doesn't hang when called with unknown command
    line arguments.
- Rebase gdm-xauthlocalhostname.patch.
* Sun May 20 2018 luc14n0@linuxmail.org
- Update to version 3.28.2:
  + Reference counting fixes for GdmClient- ensure plymouth is quit
    properly even when local greeter is disabled.
  + Make sure GDM doesn't hang when called with unknown command
    line arguments.
  + Updated translations.
* Thu May  3 2018 fezhang@suse.com
- Drop gdm-quit-plymouth-on-headless.patch: Patch is known to cause
  the first login to fail, a reworked patch needed.
* Mon Apr 23 2018 fezhang@suse.com
- Add gdm-quit-plymouth-on-headless.patch: Stop boot splash
  whenever a display is managed, to avoid systems without monitor
  from hanging (boo#1089673 bgo#795477).
* Fri Apr 13 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Properly stop boot splash even if local login screen is
    disabled (bsc#1083646 bgo#795120).
  + Updated translations.
* Tue Apr 10 2018 yfjiang@suse.com
- Add gdm-quit-plymouth-when-xdmcp-is-the-only-allowed-connection.patch:
  gdm is responsible to kill plymouth by spawning the "plymouth
  quit" subprocesses in gdm-manager. The current code pathes of
  quiting plymouth can never be reached when xdmcp is the only
  connection allowed. The patch handles this edge case by quit
  plymouth immediately when the condition is detected (bsc#1083646
  bgo#795120).
* Sun Apr  8 2018 fezhang@suse.com
- Rename gdm-disable-wayland-on-mgag200-chipsets.patch to
  gdm-disable-wayland-on-unsupported-chipsets.patch: add rules for
  ASPEED ast drivers (boo#1088539).
* Wed Apr  4 2018 fezhang@suse.com
- Clean up specfile: Enable Wayland unconditionally.
* Thu Mar 22 2018 hpj@suse.com
- Retire gdm-xwayland-xauth.patch (bsc#1084737): We now do this
  in the compositor instead.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Fri Mar 16 2018 fcrozat@suse.com
- Add requirement on xdm package, it provides common scripts and
  systemd service used by display managers (bsc#1084655).
* Wed Mar 14 2018 hpj@suse.com
- Add gdm-xwayland-xauth.patch (bsc#1084737): Creates an Xauthority
  file and exports XAUTHORITY for Xwayland.
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Mon Mar 12 2018 yfjiang@suse.com
- Add gdm-disable-wayland-on-mgag200-chipsets.patch: by falling
  back GNOME to X, the patch targets to provide a better user
  experiences for servers with mgag200 graphic chips, which suffer
  the sluggish keyboard/mouse issues running GNOME on wayland
  (bsc#1073550, bsc#1077802). Some of the servers could not
  initiate GNOME in a similar context (bsc#1070933).
  With the complexity of the problem, Wayland probably needs
  further track to get the specific hardware adapted. At the
  same time the issue itself is tracked in upstream
  (glgo#GNOME/mutter/issues/59), the better way for now to make
  SLE-15 working smoothly is to disable the chipset on Wayland
  (bsc#1083609, bgo#794106).
  In addition, the patch updates the comments section in
  data/61-gdm.rules to make the context easier to append.
* Wed Mar  7 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Updated translations.
* Fri Mar  2 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Mar  2 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Ensure default session for user gets reported to login screen
    up front.
  + Updated translations.
- Drop
  gdm-Revert-session-don-t-call-gdm_session_defaults_chang.patch:
  fixed upstream.
* Fri Mar  2 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Add support for configuration from /run.
  + Add udev rule to disable wayland with cirrus.
  + Remove obsolete stuff about Xnest from configure.
  + Adjust for g-s-d plugin removal.
  + Segfault fix in error condition for session wrappers.
  + Misc warning fixes.
  + Updated translations.
- Drop gdm-disable-wayland-on-unsupported-chipsets.patch: fixed
  upstream.
* Fri Mar  2 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + Fix for invalid DISPLAY/XAUTHORITY in session scripts.
  + Fix for keyring integration on multidisk systems.
  + Set GROUP environment variable.
  + Deprecation fixes.
  + Updated translations.
- Drop gdm-not-run-with-bogus-DISPLAY-XAUTHORITY.patch and
  gdm-nb-translations.patch: fixed upstream.
- Drop gdm-passwordless-login.patch: This patch has been disabled
  since GDM 3.5.4 (July 2012).
- Drop: gdm-workaround-boo971852.patch: patch has been disabled
  since May 2016.
* Fri Mar  2 2018 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Don't call gdm_session_defaults_changed from setup.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
- Remove obsolete %%clean section as RPM already do this kind of
  work itself.
- Update typelib-1_0-Gdm-1_0 package's summary to make it shorter
  but still meaningful.
- Update gdmflexiserver package's summary to avoid redundancies and
  correct name case in the description.
* Fri Mar  2 2018 xwang@suse.com
- Add gdm-Revert-session-don-t-call-gdm_session_defaults_chang.patch:
  fix showing right active session of user in login dialog
  (bsc#1082958 bgo#793609).
* Thu Mar  1 2018 xwang@suse.com
- Remove gdm-default-wm-sle12.patch: default session in SLE15
  becomes 'GNOME', don't need this patch anymore.
* Wed Jan 31 2018 yfjiang@suse.com
- Add back translation-update-upstream as BuildRequires since
  SLE still needs it.
* Tue Jan 30 2018 yfjiang@suse.com
- Update gdm-disable-wayland-on-unsupported-chipsets.patch: examine
  filename argument in gdm_settings_desktop_backend_new instead of
  examining GDM_RUNTIME_CONF (bsc#1078030).
* Fri Jan 26 2018 msrb@suse.com
- Add runtime option to start X under root instead of regular user.
  Necessary if no DRI drivers are present. (bnc#1075805)
  * gdm-add-runtime-option-to-disable-starting-X-server-as-u.patch
  * Updated X11-displaymanager-gdm to set the
    GDM_DISABLE_USER_DISPLAY_SERVER variable when needed.
* Fri Jan 19 2018 fezhang@suse.com
- Add gdm-disable-wayland-on-unsupported-chipsets.patch: let udev
  write to a runtime config file to disable Wayland for gdm on
  chipsets where Wayland is not supported yet, e.g. Cirrus
  (boo#1059356, bgo#789081).
- Update gdm-sysconfig-settings.patch: parts of this openSUSE
  specific patch are splitted and merged into
  gdm-disable-wayland-on-unsupported-chipsets.patch to push to
  upstream,
* Wed Jan 10 2018 zaitor@opensuse.org
- Add gdm-nb-translations.patch: Update Norwegian Bokmål
  translations.
- Drop gdmflexiserver Obsoletes from main package, we ship
  gdmflexiserver again, so this is not needed nor wanted.
- Do minor spec-cleanup, silence a couple of rpmlint warnings.
* Tue Jan  9 2018 xwang@suse.com
- Add gdm-not-run-with-bogus-DISPLAY-XAUTHORITY.patch: When run
  PreSession script, don't set DISPLAY and XAUTHORITY environment
  variable, avoiding environment variable equal (null)
  (bsc#1068016 bgo#792150).
- Remove gdm-ignore-SLE-CLASSIC-MODE.patch: SLE-Classic doesn't use
  environment variable SLE_CLASSIC_MODE anymore.
* Tue Nov 28 2017 qzhao@suse.com
- Add gdm-disable-gnome-initial-setup.patch (sle-only): Force
  gnome-initial-setup can't start before gdm, g-i-s will only
  serve for CJK people to choose the input-method after login
  (bnc#1067976).
* Thu Nov  2 2017 xwang@suse.com
- Update gdm-ignore-duplicate-session.patch: Fix patch doesn't work
  when wayland is disabled (bsc#1060627).
* Wed Nov  1 2017 fezhang@suse.com
- Update to version 3.26.2.1:
  + Fix newly introduced race leading to crash for some users.
* Mon Oct 30 2017 luc14n0@linuxmail.org
- Update to version 3.26.2:
  + Use dconf to force vitruvian man on panel.
  + Hide -xorg sessions under X11.
  + Don't add bogus wtmp entries.
  + Wait for X server to die before respawning.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Projects/GDM: current GDM's
  project page.
- Add the following BuildRequires based on configure.ac: gio-2.0,
  gio-unix-2.0, glib-2.0, gobject-2.0, gthread-2.0 and xcb.
- Add fdupes BuildRequires: removal of duplicates.
- Run spec-cleaner to get the respective pkgconfigs from
  check-devel, iso-codes-devel, libXdmcp-devel, libXi-devel,
  libXinerama-devel, gobject-introspection-devel: pkgconfig(*)
  check, iso-codes, xdmcp, xi, xinerama and gobject-introspection.
- Drop %%glib2_gsettings_schema_requires macro: not needed/used
  anymore thanks to file triggers.
* Wed Oct 18 2017 xwang@suse.com
- Add gdm-ignore-duplicate-session.patch: Fix gdm session entries
  duplicate (bsc#1060627).
* Thu Oct 12 2017 dimstar@opensuse.org
- Have update-alternatives handle Xinit's integration of the
  displaymanager, replacing /etc/sysconfig/displaymanager
  (boo#1053863).
- Drop usage of glib2_gsettings_schema_* and icon_theme_cache_*
  scriptlets, since this is handled by file triggers now.
* Wed Oct  4 2017 dimstar@opensuse.org
- Update to version 3.26.1:
  + Check for Xwayland before agreeing to do wayland.
  + Misc wayland fixes.
  + Xdmcp fixes.
  + Minor clean ups.
  + Allow gnome initial-setup to be forced from kernel command
    line.
  + Updated translations.
- Drop gdm-check-for-Xwayland.patch: fixed upstream.
- Rebase gdm-plymouth-vt1.patch and gdm-xauthlocalhostname.patch.
* Thu Sep 28 2017 xwang@suse.com
- Add gdm-ignore-SLE-CLASSIC-MODE.patch: Ignore env
  SLE_CLASSIC_MODE variable when switching from sle-classic session
  to gnome-classic session (bsc#1060630).
* Mon Sep 18 2017 fcrozat@suse.com
- Add gdm-check-for-Xwayland.patch: don't try wayland session if
  Xwayland isn't installed on the system (bgo#787837).
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Fix for unauthenticated unlock when autologin is enabled
    (CVE-2017-12164).
  + Updated translations.
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Fix for going to normal mode after classic.
  + Crasher fix when user switching.
  + Make sure reauthentication is run in right context.
  + Send hangup signal to gdm when systemctl request reload.
  + Updated translations.
- Rebase gdm-sysconfig-settings.patch.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Fix breakage in greeter and initial setup.
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Fix for going to normal mode after classic.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Aug 14 2017 fezhang@suse.com
- Drop gdm-user-logout-issue.patch: fixed upstream when the
  implementations was refactored.
* Mon Jul 24 2017 dimstar@opensuse.org
- Do not BuildRequire pkgconfig(xorg-server) on s390(x). There are
  no graphic devices on s390x and Xorg is not in use.
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.25.4.1:
  + Brown bag release to fix conflict with latest g-s-d release.
- Changes from version 3.25.4:
  + Wayland w/ --disable-user-display-server fix.
  + Make login screen session separate from user session again.
  + Updated translations.
* Tue Jul 18 2017 zaitor@opensuse.org
- Update to version 3.25.3:
  + Crasher fix.
  + X11/wayland selection fix.
  + Greeter lifecycle fix.
  + Systemd unit installation fix.
  + Drop lock down of non-existent setting.
  + Updated translations.
* Sun Jul 16 2017 tyang@suse.com
- Fix specfile: Set attributes of /var/log/gdm and /run/gdm to
  (711, root, gdm), which is hardcoded in commit c3cba52, otherwise
  modified permissions are inspected when the gdm daemon starts
  (bsc#882032, bgo#693679).
* Tue May 30 2017 dimstar@opensuse.org
- Update to version 3.24.2:
  + Update session type when we know username (and user's session).
  + Fix bug leading to reauthentication happening outside the
    session.
  + Make sure greeter is killed and reaped when gdm is restarted.
- Drop gdm-desktop-session-env-pam.patch: not required for a long
  time, as gnome-keyring pam module is using only_if for a long
  time already.
* Wed Apr 19 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Don't set DCONF_PROFILE for gnome-initial-setup.
  + Remove deprecated a11y keys.
  + Autologin fixes.
  + Xdmcp fixes.
  + User switching fixes.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + No changes.
* Mon Mar 13 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Be more robust against misconfigured autologin systems.
* Sun Mar 12 2017 zaitor@opensuse.org
- Update to version 3.23.91.1:
  + Fix regression in wayland fallback code.
  + Fix for headless sessions.
  + Change around how PostLogin/PostSession scripts are run.
  + Fix XDMCP in network environments with poor network resolution
    (bgo#779499 boo#1086600).
  + Don't try to user switch with XDMCP.
  + Updated translations.
* Sat Mar 11 2017 kukuk@suse.de
- Require group video
* Tue Feb 28 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Small fix to environment variable importing.
  + Add configure knob to turn off user X server.
* Tue Jan 10 2017 adrien.plazas@suse.com
- Drop requirement on xorg-x11-server-extra: it provides Xdmx,
  Xephyr and Xnest, which usage is strongly discouraged nowadays
  since the protocols they implement are insecure and work badly on
  GNOME 3. Other remoting protocols like VNC are recommended
  instead.
* Mon Jan  9 2017 dimstar@opensuse.org
- Update to version 3.23.4:
  + Make X11DisplayName property accurate.
  + Fix bug that forced wayland on second logins even if user
    didn't pick it.
  + Kill clients from display on logout (multiseat and xdmcp only).
  + Send hangup to process group when session exits.
  + Allow specifying pam_gdm install location to configure.
- Pass --with-pam-mod-dir=/%%{_lib}/security to configure: directly
  install the pam module into the right location instead of moving
  it there later on.
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Fix wayland login after Xorg logout for a user.
  + Prefer /usr/bin/X to /usr/bin/Xorg.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Autologin fixes.
  + Updated translations.
* Wed Aug 31 2016 dimstar@opensuse.org
- Rebase gdm-xauthlocalhostname.patch: boo#538064 is still
  applicable and the patch still required.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Fix autologin on non-LUKS systems.
  + Import environment from systemd user manager.
* Thu Aug 25 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Use LUKS password to unlock gnome-keyring at login (when
    autologin is enabled).
  + Updated translations.
- Add keyutils-devel BuildRequires: new dependency.
- Add pam_gdm.so and pam_gnome_keyring.so as optional auth modules
  to gdm-autologin.pamd: allows to unlock the gnome-keyring when
  autologin is configured, the disk is encrypted (key cached by
  systemd) and the gnome-keyring uses the same password as the
  disk,
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Small crasher fix.
  + Updated translations.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Updated translations.
- Changes from version 3.21.2:
  + Import DISPLAY into user bus.
  + Updated translations.
* Tue Aug 16 2016 tyang@suse.com
- Add gdm-fails-to-restart-gnome-shell.patch: Gdm should stop after
  a few times fails (bgo#769969, bsc#981976).
* Wed May 25 2016 zaitor@opensuse.org
- Disable gdm-workaround-boo971852.patch.
* Fri May 20 2016 dimstar@opensuse.org
- Drop insserv_cleanup call in %%postun and %%insserv_prereq macro
  in preamble.
* Tue Apr 19 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Fix passwordless logins on Debian/Ubuntu.
  + Don't allow passwordless XDMCP logins.
  + Fix redhat pam configuration.
  + Updated translations.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0 (FATE#318572):
  + Updated translations.
* Mon Mar 21 2016 zaitor@opensuse.org
- Add gdm-workaround-boo971852.patch: Workaround decision to show
  a basic xsession to all users as a workaround for non-working
  DEs. A user of gdm always has a working gnome-shell installed, or
  gdm itself would not work.
* Wed Mar 16 2016 zaitor@opensuse.org
- Update to version 3.19.92:
  + Leak fix.
  + Updated translations.
* Wed Mar  2 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Fix log output.
  + Fix timed login.
  + Fix openembedded pam configuration.
  + Updated translations.
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Better build goo output.
  + Support dbus user bus better.
  + Fix bug that prevents wayland sessions from being wayland
    sometimes.
  + Updated translations.
- Rebase gdm-desktop-session-env-pam.patch.
* Fri Feb 12 2016 zaitor@opensuse.org
- Drop gdm-xdmcp-display-this-shouldn-t-be-an-abstract-type.patch:
  Already upstream for 3.19 branch.
* Wed Feb 10 2016 fcrozat@suse.com
- Add gdm-xdmcp-display-this-shouldn-t-be-an-abstract-type.patch:
  fix xdmcp not working at all (bgo#757714).
* Mon Jan 25 2016 zaitor@opensuse.org
- Update to version 3.19.4.1:
  + Fix crasher introduced in 3.19.4.
  + Updated translations.
* Fri Jan 22 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Don't override PAM message for password change.
  + Disable GVFS when we don't need it.
  + Fail better when no sessions are installed.
  + Support gnome-session in different PREFIX than GDM.
  + Doc updates.
  + Ensure unlock screen gets told when verification completes.
  + Updated translations.
- Drop gdm-really-disable-wayland.patch: fixed upstream.
* Tue Jan 12 2016 fcrozat@suse.com
- Allow to disable wayland support and add patch
  gdm-really-disable-wayland.patch (bgo#760518).
* Tue Dec 29 2015 zaitor@opensuse.org
- Replace libcanberra-devel for pkgconfig(libcanberra-gtk3)
  BuildRequires: It's what configure looks for and needed now that
  libcanberra-devel was split.
- Add explicit pkgconfig(gtk+-3.0) BuildRequires: It used to be
  pulled in by libcanberra-devel
* Mon Dec 28 2015 zaitor@opensuse.org
- Stop pretending we can support a non systemd setup:
  + Remove %%{with_systemd} and it's define.
  + Drop conditional ConsoleKit-x11 Requires.
  + Stop passing conditional --with-consolekit-directory,
  - -without-systemd and --with-console-kit.
  + Removed conditon on pkgconfig(libsystemd) BuildRequires.
  + Stop passing --with-systemd: No longer needed, nor recognized.
* Sun Dec 27 2015 damjanovic.ivo@gmail.com
- Drop gnome-session-wayland Requires: No longer needed, nor
  provided.
- Pass --enable-systemd-journal to configure: Ensure we support it.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.2:
  + Get rid of "custom" session.
  + Separate X sessions and Wayland sessions.
  + Hide Wayland sessions if the login screen is on X.
  + Pass session mode to the shell via environment.
  + Rename gnome-wayland session to gnome.
  + Use -listen instead of -nolisten for new Xorg.
- Rebase gdm-default-wm.patch.
- Add pkgconfig(xorg-server) BuildRequires: configure needs access
  to this .pc file in order to decide what options to pass to Xorg.
* Tue Nov 17 2015 zaitor@opensuse.org
- Update to version 3.18.2 (boo#955552):
  + Fix lock screen bypass when holding escape key (CVE-2015-7496,
    bgo#758032).
  + Updated translations.
* Tue Nov 10 2015 zaitor@opensuse.org
- Drop gdm-session-emit-verification-complete-for-logins.patch: Bug
  fixed in gnome-shell.
* Sun Oct 25 2015 zaitor@opensuse.org
- Add gdm-session-emit-verification-complete-for-logins.patch: Fix
  hang on login on when using Nvidia blob driver (bgo#754814).
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fix log out after autologin.
  + Updated translations.
* Tue Aug 25 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Fix GDM_LANG corruption that sometimes fails login.
  + Rework wtmp handling.
  + Code clean ups.
  + Updated translations.
* Mon Jul 20 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Fixes to handle gdm restarts better.
  + Crasher fix on logout of wayland session.
  + Systemd build updates.
  + Updated translations.
- Replace pkgconfig(libsystemd-daemon),
  pkgconfig(libsystemd-journal) and pkgconfig(libsystemd-login) for
  pkgconfig(libsystemd) BuildRequries following upstream changes.
* Thu Jul  2 2015 dimstar@opensuse.org
- Update to version 3.17.3.1:
  + Ship systemd unit file.
- Changes from version 3.17.3:
  + Support env.d directory for manipulating session environment.
  + Drop ConsoleKit support.
  + Updated translations.
- Rebase gdm-desktop-session-env-pam.patch.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + BSD fixes.
  + Don't build Xsession by default.
  + Fix monitor hotplug segfault.
  + kdbus fixes.
  + Updated translations.
- Pass new option --enable-gdm-xsession to configure.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Add support for env.d directory (useful for xdg-app).
  + bsd fix ups.
  + Don't start dbus-daemon if kdbus is in charge.
  + Various crash fixes.
  + Updated translations.
* Thu Apr 16 2015 zaitor@opensuse.org
- Update to version 3.16.1.1:
  + Fix double free introduced in 3.16.1 (bgo#747310).
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Set XORG_RUN_AS_USER_OK=1 to tell the X server it's okay to
    drop privileges.
  + Fix wtmp handling.
  + ConsoleKit fixes for BSDs.
  + Make sure plymouth is quit if GDM fails to start.
  + make sure objects are nullified in dispose handlers.
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0.1:
  + Fix plymouth quitting that broke in 3.15.92.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Correct logic inversion in debugging features comment in
    /etc/gdm/custom.conf.
  + Updated translations.
* Fri Mar 20 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Fix user-switching for autologin.
  + Fix flicker between boot splash and login screen.
  + Fix timed login.
  + Systemd unit fixes.
  + ConsoleKit fixes.
  + Misc cleanups.
  + Document debugging features in custom.conf.
  + Die more forcefully if we can't set up the ttys the way we
    want.
  + Updated translations.
- Rebase gdm-sysconfig-settings.patch.
* Tue Mar 17 2015 dliang@suse.com
- Add "auth requisite pam_nologin.so" to gdm.pamd,
  gdm-autologin.pamd gdm-fingerprint.pamd and
  gdm-smartcard.pamd: respect /etc/nologin (bsc#897316).
* Wed Mar  4 2015 dimstar@opensuse.org
- Add gnome-session-wayland Requires: current GDM is based on a
  wayland session. The user can still choose between a X and a
  wayland session.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91.2:
  + Fix hang on logout of wayland.
  + Drop caribou autostart file.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91.1:
  + Fix hang on VT switch.
  + Updated translations.
* Sat Feb 28 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Improved debug output.
  + More X-without-root fixes.
  + Pass LANG to gdm daemon.
  + Fix hang with autologin.
  + Less flicker with wayland.
* Fri Feb 27 2015 fcrozat@suse.com
- Drop gdm-correct-ShowLocalGreeter-standalone-XDMCP-server.patch:
  merged upstream.
- Rebase gdm-passwordless-login.patch.
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 3.15.90.5:
  + Code clarification.
  + Initial Setup fixes.
  + X-without-root fixes.
  + Updated translations.
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 3.15.90.4:
  + Pass DISPLAY/XAUTHORITY to dbus-daemon.
  + Updated translations.
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 3.15.90.3:
  + Disable gnome-initial-setup for now.
  + One more stab at the widespread "No user list" problem.
  + Fix X session environment to use provided dbus-daemon.
  + Updated translations.
- Changes from version 3.15.90.2:
  + Fix crashers in gdm-wayland-session and gdm-x-session.
  + Start dbus-daemon in more platform agnostic way.
  + clean up log spew.
  + fix accountsservice race leading to gnome-shell tanking on
    startup for some people.
- Drop gdm-fix-crash.patch: fixed upstream.
* Fri Feb 27 2015 dimstar@opensuse.org
- Add gdm-fix-crash.patch: Fix crashes due to dbus-daemon not being
  found in /usr/bin.
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Fix daemon/WaylandEnable check.
  + Compiler warning fixes.
  + Updated translations.
- Drop gdm-returnvalues.patch: fixed upstream.
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Fix pam_ecryptfs on Fedora.
  + Launch user sessions on a separate VT from login screen for
    seat0.
  + Use wayland by default on login screen (can turn off with
    daemon/WaylandEnable=false) (bgo#744763), (fixed bsc#984620 as
    a side effect).
  + Deprecate ConsoleKit and disable by default.
  + Significant code clean ups.
  + Fix xdmcp/ShowLocalGreeter config option.
  + Memory leak fixes.
  + Updated translations.
- Rebase gdm-passwordless-login.patch.
- Drop gdm-look-at-runlevel.patch: no longer applicable after the
  refactoring.
- Add gdm-returnvalues.patch: Ensure functions have a return value.
* Thu Feb 26 2015 fcrozat@suse.com
- Update gdm-sysconfig-settings.patch / X11-displaymanager-gdm: fix
  support for DISPLAYMANAGER_STARTS_XSERVER from
  /etc/sysconfig/displaymanager (bsc#919723).
- Add gdm-correct-ShowLocalGreeter-standalone-XDMCP-server.patch:
  ensure ShowLocalGreeter configuration key is properly handled
  (bgo#743440).
* Tue Feb 10 2015 zaitor@opensuse.org
- Only install gdm-fingerprint and gdm-smartcard pamfiles if
  enable_split_authentication is enabled (boo#900836).
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.3.1:
  + Actually set XDG_SESSION_TYPE in user sessions.
  + Don't require plymouth if using systemd.
  + Require --without-plymouth to disable plymouth support.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Set XDG_SESSION_TYPE in user sessions.
  + Propagate XDG_CONFIG_DIRS and XCURSOR_PATH into login sessions.
  + Require plymouth if using systemd.
* Fri Nov 28 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + Fix session selection for smartcard users.
  + Don't warp pointer anymore.
  + Updated translations.
* Tue Oct 14 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Update fedora PAM config to be more tolerant of /etc/nologin.
  + leak fixes in libgdm.
  + Fix spew on console generated from conversations that get
    cancelled when they're closing.
  + Drop some lingering fallback greeter cruft.
  + Updated translations.
* Sun Oct 12 2014 crrodriguez@opensuse.org
- Drop unused libattr-devel BuildRequires.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Wed Sep 17 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Compat fixes to work with latest caribou.
  + Minor code clean up.
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Fix crash when typing password at screen lock.
  + Fix default signal mask of session to not block SIGUSR1.
  + Memory leak fixes.
  + Fix for when building without consolekit.
  + Fix autologin pam config on GNOME Continuous.
  + Fix timed login race.
  + Again read LANG from accountsservice.
  + Misc fixes.
  + Updated translations.
* Wed Jul  2 2014 cxiong@suse.com
- Add gdm-default-wm-sle12.patch:
  + Set the default/fallback session type to SLE Classic
    (bnc#881659).
* Fri Jun 27 2014 fcrozat@suse.com
- Add gdm-plymouth-vt1.patch: switch back to VT1 when terminating
  gdm, if plymouth was running at startup (bnc#881676).
* Mon Jun 23 2014 dimstar@opensuse.org
- Really drop gdm-greeter-greater-ui.patch: it has been removed
  during the 3.9.5 update, but the patch file was not deleted.
* Fri Jun 20 2014 fcrozat@suse.com
- Update X11-displaymanager-gdm: remove call to splashcopy, useless
  with plymouth.
* Wed May 28 2014 fcrozat@suse.com
- Remove scrollkeeper configure flag, no longer exists.
- Only build ConsoleKit support when not building systemd support.
- Update gdm-launch-environment.pamd to not call pam_loginuid, it
  was causing gdm logind session to not be detected as a greeter
  session (bnc#871808).
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Work around ugly "Last Login" messages in fedora.
  + Fix PATH variable.
  + Fix undead worker processes.
  * Drop gdm-launch-environment-explicitly-kill-worker-on-stop-ev.patch.
  + Fix crash on logout after user switching.
* Tue Apr 15 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Drop dead code.
  + support XDG_CURRENT_DESKTOP (bsc#981261, bgo#727546).
  + Fix PID file in build goo.
  + doap file fix ups.
  + Improve Fedora PAM config with regard to gnome-keyring.
  + Small wayland fixes.
  + ConsoleKit fixes.
  + Fixes to non-GDM session unlock corner cases.
  + Updated translations.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Fix automatic login.
  + Fix timed login.
  + Updated translations.
* Thu Mar 20 2014 dimstar@opensuse.org
- Update to version 3.11.92.1:
  + BSD build fixes.
- Changes from version 3.11.92:
  + BSD build fixes.
  + Experimental Wayland support.
  + Support gnome-shell unlocking from non GDM sessions
    (bsc#889094, bgo#726283).
  + Drop slave process.
  * Drop gdm-leaks-slave.patch.
  + Onscreen keyboard support at login screen.
  + Updated translations.
- Rebase gdm-desktop-session-env-pam.patch.
- Copy autogen.sh to PWD instead of launching it from the SOURCE
  directory.
- Synchronize autogen.sh with gdm git tree.
* Fri Feb 21 2014 dimstar@opensuse.org
- Update to version 3.11.90:
  + Code clean ups.
  + Leak fixes.
  + Log X server to systemd journal.
  + Log fixes on none systemd systems.
  * Drop gdm-disable-journal.patch.
  + Fail better when invoked wrong.
  + Change how dconf settings are used.
  + FreeBSD build fixes.
  + Updated translations.
- Rebase gdm-desktop-session-env-pam.patch,
  gdm-passwordless-login.patch and gdm-sysconfig-settings.patch.
- Disable gdm-xauthlocalhostname.patch: Needs rebasing.
* Wed Jan 15 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Treat '' returned from a PAM module as "no username set" in the
    same way NULL is (bgo#721803).
  * Drop gdm-worker-ignore-username.patch.
  + Fix to work with more open dbus policy.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Infinite loop fix.
  * Drop gdm-slave-fix-infinite-loop-on-shutdown.patch.
  + Require debugging to be explicitly enabled in unstable
    versions.
  + Pass LC_ vars from system to user session.
  + Fix PAM reauthentication.
  + Updated translations.
- Drop gdm-is-not-unstable-unless.patch: debugging is no longer
  enabled by default on unstable releases.
* Thu Nov 28 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + XDMCP fixes (bgo#567522).
  - Drop gdm-standalone-xdmcp-server.patch.
  + BSD portability fixes.
  + Assorted changes to build goop.
  + Updated translations.
- Pass --with-gnome-settings-daemon-directory to configure.
- Drop gdm-XDMCP-fixes.patch: fixed upstream.
* Wed Nov 27 2013 tyang@suse.com
- Add gdm-user-logout-issue.patch: Fix user logout causes black
  screen when switching (bnc#940159).
* Wed Nov 27 2013 fcrozat@suse.com
- Add gdm-disable-journal.patch: properly disable journald in all
  gdm, if asked (bnc#867344).
- Add gdm-leaks-slave.patch: fix gdm slave not killing Xorg on stop
  (bnc#871808).
- Add gdm-worker-ignore-username.patch: fix crash when pam returns
  empty username (bgo#721803).
- Add gdm-launch-environment-explicitly-kill-worker-on-stop-ev.patch:
  fix leak of gdm-launch-environment (bnc#871808, bgo#729727).
- Add gdm-slave-fix-infinite-loop-on-shutdown.patch: fix infinite
  loop on shutdown (bnc#871808, bgo#712767).
- Add gdm-standalone-xdmcp-server.patch (bgo#567522).
* Wed Nov 27 2013 dliang@suse.com
- Add --disable-systemd-journal in specfile for SLE to disable
  journal support (bnc#867344).
* Wed Nov 27 2013 dimstar@opensuse.org
- Add gdm-XDMCP-fixes.patch: Backports fixes in git
  addressing XDMCP related issues (bnc#851160, bgo#690926,
  bgo#711180).
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.0.1:
  + Don't say we're updating btmp when we aren't.
  + PAM updates for exherbo/lfs.
  + Updated translations.
* Thu Sep 26 2013 vuntz@suse.com
- Remove dependencies from the old days:
  + No metacity nor polkit-gnome Requires: this was for fallback
    mode.
  + Promote gnome-shell from Recommends to Requires.
  + Drop commented out accessibility Recommends (gnome-mag, gok)
    from GNOME 2.x.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
- Add autogen.sh as source (extracted from git). GDM actually does
  not use gnome-autogen.sh to bootstrap; this just happened to work
  so far. The correct way is to use upstreams autogen.sh script.
- Replace gnome-autogen.sh call with autogen.sh (based on added
  source).
* Thu Sep 19 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Drop references to unused AUTHDIR directory.
  + Fix up gdmflexiserver's loginscreen identification code.
  + Assume PAM_RADIO_TYPE is a "yes/no" question.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Drop cruft from configure file.
  + Drop dead PAM code.
  + Fix spew on shutdown.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Make selinux explicitly build time optional.
  + Update pam config files for LFS.
  + Tell user when their password is expired.
  + Fix crasher when logging in and out quickly.
  + Various auth session fixes.
  + Enable smartcard authentication by default.
  + Add setting for disabling password authentication.
  + Give more friendly messages on password failure.
  + Updated translations.
- Rebase gdm-desktop-session-env-pam.patch.
- Drop gdm-greeter-greater-ui.patch and
  gdm-always-reflect-keyboard-layout.patch: simple greeter has been
  dropped.
- Drop libgdmsimplegreeter1 subpackage: the simple greeter has
  been dropped.
- No longer Provide / Obsolete libgdmsimplegreeter-devel from the
  - devel package: with the drop of the simple greeter, this is no
  longer provided.
* Tue Jul  2 2013 dimstar@opensuse.org
- Update X11-displaymanager-gdm (bnc#827236): Override
  PIDFILE=/run/gdm/gdm.pid in gdm_vars().
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.8.3.1:
  + Add back fallback greeter.
- Changes from version 3.8.3:
  + Drop configure flag that doesn't do anything
    (--with-incomplete-locales).
  + Fix warning on shutdown.
  + ConsoleKit fix.
  + Support logind without systemd.
  + Stop setting KRB5CCNAME again.
  + Various gnome-initial-setup fixes.
  + Updated translations.
* Fri Apr 19 2013 dimstar@opensuse.org
- Update to version 3.8.1.1:
  + Fix a race with accountsservice D-Bus calls that was leading to
    crashes.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Use common pam stacks for openembedded.
  + Only launch gnome-initial-setup if there are no user accounts.
  + Check for logind, not for systemd.
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + No changes since version 3.7.92.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Add --disable-fallback-greeter configure option.
  + Updated translations.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Correct path of run dir.
  + Don't set _XROOTPMAP_ID at startup anymore.
  + Updated translations.
* Fri Mar  1 2013 dimstar@opensuse.org
- Drop klogd Requires: this is no longer needed due to the changes
  with earlygdm / systemd integration.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Add gdm-pin service file.
  + use 0711 for directories.
  + don't enable systemd journal if systemd is disabled.
  + Add a --with-run-dir.
  + Start to land prerequisite bits needed for future
    systemd-ification.
- Drop gdm-move-everything-to-run.patch: fixed upstream (slightly
  different)
- Pass --with-run-dir=/run/gdm to configure.
* Tue Feb  5 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Randr performance improvement
  + Remove gdm wrapper script
  + Integrate better with systemd journal
  + Use glib signal handling helpers instead of home brew ones
  + Don't load gio modules in launch environment
  + Enable gsd keyboard plugin in launch environment
  + Don't warp pointer to 0,0
  + Don't record a login uid for gdm's login session
  + Other misc fixes
  + Updated translations.
- Add pkgconfig(libsystemd-journal) BuildRequries: new dependency.
* Tue Jan 29 2013 dimstar@opensuse.org
- Update to version 3.7.3.1:
  + Fix xauthoriation for su/ssh compatibility.
- Changes from version 3.7.3:
  + Drop dead code.
  + Deprecation fixes.
  + Compiler warning fixes.
  + Change default location of language config file.
  + Be more resiliant against hostname changes.
  + Fix spew in error path.
- Changes from version 3.7.2:
  + Ignore pam info messages for automatic logins
  + Unlock fixes
  + User switching fix on consolekit systems
  + Be more robust against empty user shells/home dirs
  + Create program session log file as root instead of after setuid
  + Properly reload gdm.schemas on SIGHUP
  + Bring back gdmflexiserver
  + Fix shutdown and restart with ConsoleKit (bgo#686125)
  + Refactor autologin conversation handling (bgo#682467)
  + Add host authorizations individually (bgo#686186)
  + Make gdm socket world accessible (bgo#685935)
  + Allow NULs in X11 cookies (bgo#687691)
  + Dont set a busy cursor (bgo#687791)
  + Use a whitelist for gsd plugins (bgo#662220)
  + Drop obsolete desktop files (bgo#684508)
  + Updated translations.
- Drop gdm-autologin-session-logout.patch: fixed upstream.
- Rebase gdm-sysconfig-settings.patch and
  gdm-xauthlocalhostname.patch.
* Mon Jan 28 2013 rmilasan@suse.com
- Add gdm-move-everything-to-run.patch: move everything (socket and
  pid files) to /run.
* Sun Jan 20 2013 dimstar@opensuse.org
- Add gdm-autologin-session-logout.patch: Fix login after logging
  out from a auto-login session (bgo#682467)
* Fri Jan 18 2013 rbrownccb@opensuse.org
- Removed fprint from gdm-fingerprint.pamd to fix YaST config.
* Thu Jan 17 2013 vuntz@opensuse.org
- Update gdm-xauthlocalhostname.patch: instead of always putting
  localhost in the Xauthority entry, we correctly set the
  XAUTHLOCALHOSTNAME environment variable to the current hostname.
  This matches what we're supposed to do as per comment 24 of
  bnc#538064.
* Fri Nov 16 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Fix occasional failure at startup.
  + Fix peer-to-peer dbus communication on BSDs.
  + Fix host based access control if gdm-initial-setup user
    doesn't exist.
  + Updated translations.
* Thu Nov 15 2012 dimstar@opensuse.org
- Do not ship gdm.service: openSUSE uses xdm to start the requested
  DisplayManager, based on sysconfig settings.
- No longer perform actions needed for openSUSE <= 11.2 (deleting
  en@shaw language files).
* Sun Nov 11 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Thu Nov  8 2012 dimstar@opensuse.org
- Switch on systemd support: change with_systemd defines to 1.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Various InitialSetup fixes
  + ignore pam info messages for automatic logins
  + unlock fixes
  + user switching fix on consolekit systems
  + be more robust against empty user shells/home dirs
  + create program session log file as root instead of after setuid
  + properly reload gdm.schemas on SIGHUP
  + bring back gdmflexiserver
  + Updated translations.
- Reintroduce gdmflexiserver subpackage and gdmflexiserver-wrapper
  source that were dropped with 3.5.90: gdmflexiserver was
  re-introduced as gnome-screensaver depends on it.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Update exherbo PAM config
  + screen reading fixes
  + start dbus-daemon inside greeter session
  + Updated translations.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92.1:
  + Fix crasher when hitting escape really fast at unlock time.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + More PAM distro changes
  + Clean up initialization code
  + export Version property over bus
  + SELinux integration
  + ConsoleKit fixes
  + Autologin fixes
  + Make reauthentication session have user's environment
  + Updated translations.
- Drop gdm-gdmslave-typo.patch: fixed upstream.
* Thu Sep 13 2012 dimstar@opensuse.org
- Add gdm-gdmslave-typo.patch: Fix typo in Method call, which can
  cause gdm to crash on login when operated with ConsoleKit.
* Tue Sep 11 2012 vuntz@opensuse.org
- Rebase gdm-desktop-session-env-pam.patch and
  gdm-passwordless-login.patch.
* Tue Sep 11 2012 vuntz@opensuse.org
- Only have a ConsoleKit-x11 Requires if we don't build with
  systemd support.
* Wed Sep  5 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Fix multi-seat
  + Memory leak fix
  + initial-setup feature fixes
  + Reauth fixes
  + Make PostLogin failures to fail login
  + More PAM distro support
  + Misc data file changes
  + More debug messages
  + Use yelp-tools for docs
  + Drop libxklavier dependency
  + Updated translations.
- Drop upstream fixed patches:
  + gdm-helper-directory.patch
  + gdm-vtswitch-nonsystemd.patch
- Rebase (and re-enable) gdm-default-wm.patch.
- Rebase (and re-enable) gdm-xauthlocalhostname.patch
- Drop libxklavier-devel BuildRequires: dependency dropped
  upstream.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstream.
- Replace intltool and libtool BuildRequires with gnome-common, as
  well as libtoolize and autoreconf calls with gnome-autogen.sh:
  the build system is too specific and some spurious errors can be
  avoided by boostrapping it the supported way.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Reauthentication fixes
  + Change user-switching mechanism from gdmflexiserver helper to
    libgdm
  + Set KRB5CCNAME environment variable for session
  + Memory leaks and other misc fixes
  + Updated translations.
- Drop gdmflexiserver subpackage and gdmflexiserver-wrapper source:
  user-switching mechanism moved to libgdm and no longer relies on
  gdmflexiserver.
- Add a gdmflexiserver Obsoletes to gdm main package, for smooth
  upgrades. Also remove the gdmflexiserver Requires that was there.
- Rename gdm-welcome.pamd to gdm-launch-environment.pamd, following
  upstreams rename.
- Add gdm-vtswitch-nonsystemd.patch: Fix vt switch when not using
  systemd.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Add initial setup integration
  + "Fix" timed login
  + Fix up ConsoleKit integration post-gdbus port
  + Code clean ups/refactoring
  + Make initial VT a ./configure option
  + Updated translations.
- Drop gdm-vt-allocation-hack.patch in favor of --with-initial-vt=7
  passed to configure.
* Thu Aug  2 2012 dimstar@opensuse.org
- Remove SELinux support (following upstream):
  + Drop libselinux-devel BuildRequires
  + Remove --with-selinux from configure call
  + Drop gdm-selinux.patch
* Fri Jul 20 2012 dimstar@opensuse.org
- Update to version 3.5.4.2:
  + Fix non autologin
  + Updated translations.
* Thu Jul 19 2012 dimstar@opensuse.org
- Update to version 3.5.4.1:
  + Fix autologin
  + Update PAM configuration for red hat distros
  + Make sure gdm-client-glue.h gets installed with libgdm
  + Change SetupForProgram interface to allow specifying a username
  + Drop GdmGreeterSession and GdmChooserSession, just use
    GdmWelcomeSession directly
  + Change dconf profile to be compatible with latest dconf
  + Fix VerificationComplete signal for external gdm clients
  + Updated translations.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Rename libgdmgreeter to libgdm and change API
  + Be less chatty in syslog
  + Reload settings on SIGHUP
  + Start polkit agent in fallback session
  + Port to gdbus
  + Deprecation fixes
  + PAM file reorganization
  + Misc fixes
  + Updated translations.
- Drop dbus-1-glib-devel BuildRequires: not needed after port to
  GDBus.
- Rebase patches:
  + gdm-helper-directory.patch
  + gdm-sysconfig-settings.patch
- Disable and mark patches for rebasing:
  + gdm-desktop-session-env-pam.patch
  + gdm-passwordless-login.patch
  + gdm-default-wm.patch
  + gdm-xauthlocalhostname.patch
- Rename libgdmgreeter1 package to libgdm1, following upstreams
  renaming of the library.
- Rename typelib-1_0-GdmGreeter-1_0 subpackage to
  typelib-1_0-Gdm-1_0
- Add copies of gdm-fingerprint.pamd and gdm-smartcard.pamd to our
  package, based on the Red Hat ones (until we upstream our
  variants, bgo#675085). Note that they won't be used since we
  don't build with enable_split_authentication.
* Sun Jul 15 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Robustness updates for greeter dbus-daemon life-cycle
    management
  + Add ability to disable documentation generation at build time
  + Add more verbosity in PAM code
  + Use systemd to shutdown from greeter
  + Use new gnome-shell mode
  + Add ability to build with plymouth support
  + Save log to $XDG_CACHE_HOME/gdm/session.log instead of
    ~/.xsession-errors
- Add pkgconfig(ply-boot-client) BuildRequires and pass
  - -with-plymouth to configure for plymouth support.
- Drop gdm-plymouth.patch: plymouth support has been upstreamed.
* Fri Jul 13 2012 vuntz@opensuse.org
- Change gdm-welcome.pamd source file to fix bnc#731867:
  + For some mysterious reason (external to the gdm package, as far
    as I can tell), the gdm account got locked on some systems in
    the past, and this made gdm simply hang on startup.
  + The gdm-welcome PAM service is only used for the gdm account in
    the gdm greeter session, so a fix to this issue is to disable
    the standard PAM account management in this gdm-welcome PAM
    service.
  + To that end, simply use pam_permit.so for account management in
    gdm-welcome instead of inclusing the usual common-account file.
* Mon Jul  9 2012 vuntz@opensuse.org
- Drop gdm-domain-logon.patch: this patch needed to be rebased, but
  nobody ever did it and bnc#627575 got closed since there's no
  interest to rebase it, apparently.
- Remove support for gnome-patch-translation since there are not
  patches adding translations left: remove gnome-patch-translation
  BuildRequires and commented out calls to
  gnome-patch-translation-prepare and
  gnome-patch-translation-update.
* Thu May 24 2012 vuntz@opensuse.org
- Re-disable systemd support as this has way too many side-effects
  with packages that are not built with systemd support like
  NetworkManager. For instance, NetworkManager doesn't work in the
  user session anymore.
- Explicitly pass --without-systemd to configure when we want to
  disable systemd support.
* Tue May 15 2012 vuntz@opensuse.org
- Re-enable systemd support on 12.2 and later, now that we have
  xorg 1.12 in Factory (bnc#753498): define with_systemd to
  "0%%{?suse_version} > 1210".
* Sun Apr 15 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Fix various problems in the systemd support code.
  + Omit locked users from the user list.
  + Updated translations.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 3.4.0.1:
  + Fix autologin
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Temporarily disable systemd support as it breaks on Factory
  because of our old Xorg (bnc#753498):
  + Add a with_systemd macro, set to 0.
  + Only use --with-systemd configure option if with_systemd is set
    to 1.
  + Only use pkgconfig(libsystemd-daemon) and
    pkgconfig(libsystemd-login) BuildRequires if with_systemd is
    set to 1.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Wed Mar 21 2012 vuntz@opensuse.org
- Also pass --with-console-kit to configure to make sure we also
  build the ConsoleKit support.
- Move %%glib2_gsettings_schema_requires from
  gdm-simple-greeter-extensions to main subpackage, where the
  GSettings schemas live.
- Update gdm-plymouth.patch with Fedora's version.
- Rebase and re-enable gdm-greeter-greater-ui.patch.
- Disable gnome-patch-translation-{prepare,update} calls in %%prep
  as they're only needed for gdm-domain-logon.patch, which needs to
  be rebased.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.92.1:
  + ConsoleKit fixes.
- Changes from version 3.3.92:
  + Only start Xorg with high verbosity when debug is enabled.
  + Land support for systemd and multi-seat.
  + Switch from GConf to GSettings.
  + Auth fixes.
  + Miscellaneous fixes.
  + Updated translations.
- Drop gdm-gconf-path.patch: not needed after port to GSettings.
- Rebase gdm-desktop-session-env-pam.patch and gdm-plymouth.patch.
- Temporarily disable gdm-greeter-greater-ui.patch: it needs to be
  rebased.
- Drop gconf2-devel BuildRequires and gconf packaging: gdm got
  ported to GSettings.
- Enable systemd support:
  + Note that it nicely falls back to ConsoleKit if systemd is not
    used on the system.
  + Pass --with-systemd to configure
  + Add pkgconfig(libsystemd-login) and
    pkgconfig(libsystemd-daemon) BuildRequires.
* Mon Feb 20 2012 vuntz@opensuse.org
- Add explicit BuildRequires after xorg-x11 packaging change:
  libXdmcp-devel, libXi-devel, libXinerama-devel, pkgconfig(x11),
  pkgconfig(xau), pkgconfig(xrandr).
* Sun Feb 12 2012 vuntz@opensuse.org
- Fix /etc/dconf/profile/gdm to exist and have valid content: we
  were using it as %%ghost, while the %%ghost file should have been
  /etc/dconf/db/gdm.
- Drop gdm-plymouth-X-nr.patch: the -nr option was Fedora specific
  and "-background none" is the right thing to use now. See
  http://pkgs.fedoraproject.org/gitweb/?p=gdm.git;a=commitdiff;h=30dd105c68d2774e7e8fee48b5c2e1d6da793abe
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.2.1.1:
  + Change the way we do dconf again (bgo#662168)
- Changes from version 3.2.1:
  + Legacy authentication fixes
  + Change the way we do dconf
  + Rearrange pam files for fingerprint/smartcard
  + Add new "disable-user-list" gsettings key
  + Allow users to connect to local $DISPLAY when ssh'd in without
    mucking with xauth
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Drop gdm-unified-auth.patch and gdm-fix-no-split-again.patch:
  fixed upstream.
- Rebase gdm-helper-directory.patch.
- Update for the new way to handle the gdm dconf database:
  + Add Requires(post) for dconf.
  + Call "dconf update" in %%posttrans to generate the dconf
    database for gdm after installation, as documented in
    bgo#662168.
  + Remove /etc/dconf/profile/gdm and touch it in %%install, so we
    can install the file as %%ghost.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GdmGreeter-1_0 subpackage.
- Add typelib-1_0-GdmGreeter-1_0 Requires to devel subpackage.
* Fri Nov  4 2011 dimstar@opensuse.org
- Make sure gdm is member of the 'video' group. This is newly
  needed as gdm uses gl as well [bnc#728259].
- Fix the scriptlet to not try to add gdm as additional group (It's
  already the primary group)
* Fri Oct 14 2011 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Fri Oct  7 2011 vuntz@opensuse.org
- Add gdm-fix-no-split-again.patch: do not crash in old
  (non-gnome-shell) greeter when trying to login.
- Rebase gdm-greeter-greater-ui.patch, fix bnc#689552.
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
- Replace gdm-unified-auth.patch with the fix from upstream.
* Sat Sep 24 2011 vuntz@opensuse.org
- Fix syntax in X11-displaymanager-gdm: this syntax error was
  causing the use of xdm instead of gdm.
* Fri Sep 23 2011 dimstar@opensuse.org
- Add gdm-unified-auth.patch: Revert 'better unified authentication
  compatibility' that was committed upstream as it breaks GDM. See
  http://lists.opensuse.org/opensuse-gnome/2011-09/msg00043.html
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Leak fixes
  + Fix autologin
  + Activate keyboard layout explicitly at startup
  + Move extensions settings to common code
  + Add setting for login screen logo to common code
  + Create empty gdm.d dconf subdir tree at install time
  + Updated translations.
- Drop gdm-fix-autologin.patch: fixed upstream.
- Update gdm-plymouth.patch: take the latest version from the
  Fedora package.
- Move calls to %%glib2_gsettings_schema_post(un) from %%post/%%postun
  of the simple-greeter-extensions subpackage to the scriptlets of
  the main subpackage, following the move of the file.
* Tue Sep 20 2011 eich@suse.com
- Install /etc/init.d/xdm integration helper in %%{_libexecdir}, not
  %%{_libdir}.
* Fri Sep 16 2011 vuntz@opensuse.org
- Add gdm-fix-autologin.patch: fix autologin, taken from git.
* Sat Sep 10 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Enable new g-s-d plugins for tablets
  + Enable maintainer mode by default
  + Greeter session handling fixes
  + Update for gnome-power-manager move to g-s-d
  + Updated translations.
- Rebase gdm-helper-directory.patch.
* Wed Sep  7 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Register greeter session with PAM
  + Add framework for gnome-shell based greeter
  + Plug xdmcp chooser leak
  + Fix problem with --disable-split-authentication
  + Switch to --enable-split-authentication by default
  + Misc other fixes and cleanups
  + Updated translations.
- Rebase gdm-helper-directory.patch: we don't need as many specific
  libexecdirs as before, as several autostart files got removed.
  Also add a --with-check-accelerated-directory flag, to specify
  where to find gnome-session-check-accelerated.
- Update gdm-desktop-session-env-pam.patch: rebase/port for pam
  multistack support, using some new function that appeared in
  the meantime to simplify.
- Rebase gdm-xauthlocalhostname.patch.
- Add explicit dbus-1-glib-devel BuildRequires: it used to be
  brought in by something else before.
- Add gobject-introspection-devel BuildRequires: new dependency for
  introspection data.
- Remove fdupes BuildRequires and %%fdupes call as it's not useful
  for this package.
- Add gnome-shell Recommends for the new gnome-session-based
  non-fallback greeter session used by gdm. It's only a Recommends
  and not a Requires so people can install gdm without pulling all
  of GNOME (as gdm will fallback to the old greeter if gnome-shell
  is missing).
- Add orca Recommends: this makes it possible to have a screen
  reader in the greeter session. This is not mandatory for the
  greeter session to work, therefore it's not a Requires.
- Create a libgdmgreeter1 subpackage for the new libgdmgreeter
  library.
- Rename libgdmsimplegreeter-devel to gdm-devel, with appropriate
  Provides/Obsoletes. This is needed as it also covers the
  libgdmgreeter library now.
- Stop passing --with-gnome-settings-daemon-directory and
  - -with-polkit-gnome-directory to configure as we removed those
  options from gdm-helper-directory.patch. However, add the
  - -with-check-accelerated-directory configure flag that got added
  to the patch.
- Add a enable_split_authentication define, to easily enable the
  split authentication feature (see bnc#699999):
  + Pass --enable-split-authentication or
  - -disable-split-authentication to configure, depending on the
    value of the macro.
  + Create simple-greeter-extensions subpackage, that contains
    non-essential (but useful) extensions for the greeter
    (fingerprint and smartcard support) when
    %%enable_split_authentication is set.
  + Stop manually creating %%{_libdir}/gdm/simple-greeter/extensions
    in %%install if %%enable_split_authentication is set since it'll
    be there already.
  + Remove /etc/pam.d/gdm-password in %%install as it will get
    replaced by our own configuration.
  + Fail the build in %%install since we need to investigate what to
    put in /etc/pam.d/gdm-{fingerprint,smartcard}.
- Fix a typo: %%{_localstatedir} instead of {_localstatedir}.
- Make sure to not package simple-greeter extensions data files
  twice, thanks to an %%exclude in the main subpackage.
- Add gdm-welcome.pamd as source file: this is the pam
  configuration file that is being used to register the gdm greeter
  session. It is actually using the same configuration as
  gdm-autologin.pamd.
- Link /etc/pam.d/gdm-password to /etc/pam.d/gdm: our standard gdm
  PAM configuration is what we want to use for password-based PAM
  conversations. We need to provide it, even if we don't built with
  split authentication as the GNOME Shell-based greeter session is
  using it.
- Add comments to gdm.pamd and gdm-autologin.pamd to explain how
  those pam configuration files are used.
* Wed Sep  7 2011 vuntz@opensuse.org
- Slightly improve gdmflexiserver-wrapper: report an error if no
  gdmflexiserver implementation is found.
- Add a gdm Suggests to the gdmflexiserver subpackage, to give a
  hint about the default implementation, if people only install the
  gdmflexiserver package.
- Reformat X11-displaymanager-gdm shell code.
* Mon Sep  5 2011 eich@suse.com
- Add /etc/init.d/xdm integration (bnc#714003):
  + Add X11-displaymanager-gdm as source file, that gets installed
    to %%{_libdir}/X11/displaymanagers/gdm.
  + This enables /etc/init.d/xdm to not know anything about gdm:
    the new file is sourced by the init script, and provides
    information about how gdm should be started.
* Wed Aug 31 2011 gber@opensuse.org
- Add a wrapper script for gdmflexiserver to enable alternative
  gdmflexiserver implementations from other display managers (like
  LightDM):
  + Add gdmflexiserver-wrapper as source file: the wrapper simply
    checks for the GDMFLEXISERVER environment variable, and falls
    back to gdm's implementation.
  + Move gdm's implementation to %%{_libexecdir}/gdm/gdmflexiserver.
  + Install the wrapper as %%{_bindir}/gdmflexiserver.
  + Create a gdmflexiserver subpackage, that contains the wrapper,
    so that other display managers can depend on it without pulling
    all of gdm.
  + Add gdmflexiserver Requires to gdm.
* Mon Jul 25 2011 vuntz@opensuse.org
- Remove gnome-power-manager Recommends, as the features are now
  provided by gnome-settings-daemon (already in Requires).
* Wed Jul 20 2011 vuntz@opensuse.org
- Update gdm-sysconfig-settings.patch to fix changing a value in
  sysconfig files. Values were not quoted, and were losing the last
  character.
- Also add a comment that we have a similar patch that needs to be
  kepts in sync with gdm-sysconfig-settings.patch in
  accountsservice.
* Wed Jul  6 2011 vuntz@opensuse.org
- Change branding-upstream subpackage:
  + Add Requires for gdm since the branding package is useless
    without it.
  + Update summary and description.
  + Make noarch.
- Change branding Requires in main subpackage to be "= %%{version}"
  since it has to be versioned.
- Update branding documentation: there is only one file left in the
  branding package.
- Update Url tag.
* Sat Jul  2 2011 vuntz@opensuse.org
- Add explicit Requires for the components of the gnome-session
  session defined and used by gdm:
  + Add metacity, polkit-gnome Requires
  + Change gnome-settings-daemon Recommends to Requires
* Wed Jun 15 2011 vuntz@opensuse.org
- Update to version 3.1.2:
  + GTK size negotiation fixes
  + Do not propagate WINDOWPATH if its unset to begin with
  + Audit fixes
  + Break cycle between greeter and slave for session notification
  + Screenshots in docs!
  + Don't hardcode path to grep
  + Fix introspection xml
  + Allow .xsession-errors to be a symlink or FIFO
  + PAM fixes
  + Dconf fixes
  + Land multi-stack
  + Updated translations.
- Add pkgconfig(nss) BuildRequires since nss is now required.
- Drop gdm-selecting-desktop-environment.patch: fixed upstream,
  another way.
- Rebase the following patches in a trivial way:
  + gdm-desktop-session-env-pam.patch
  + gdm-plymouth.patch
  + gdm-sysconfig-settings.patch
  + gdm-xauthlocalhostname.patch
- Rebase and optimize gdm-passwordless-login.patch thanks to code
  changes.
- Update descriptions of packages, based on text from README.
- Add libgdmsimplegreeter1 and libgdmsimplegreeter-devel
  subpackages for new library used to write greeter plugins.
- Pass --disable-static to configure and remove .la files.
- Create the directory where greeter plugins are put, if it doesn't
  already exist, so we can package it.
- Fix permissions of /var/lib/gdm/.local directory in file list.
* Tue May 31 2011 fcrozat@novell.com
- Update to version 3.0.4:
  + Ship valid dconf database
- Changes from version 3.0.3:
  + Register /bin/true as URI scheme handler for several schemas
    (CVE-2011-1709).
  + Updated translations.
- Package files from /var/lib/gdm/.local
* Mon May 23 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Crasher fixes
  + Force symbolic icons in panel
  + Update copyright notices
  + Updated translations.
* Mon Apr 25 2011 vuntz@opensuse.org
- Drop zenity BuildRequires: it's not needed during the build
  anymore.
* Tue Apr 12 2011 fcrozat@novell.com
- Remove gnome-panel-devel BuildRequires as the fast-user-switch
  applet was removed.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.94:
  + Warp pointer to convenient place at start up
  + Fix crash with autologin
  + Don't show empty names in user list
  + Add a gdm session file for gnome-session to use
  + Fix fuzzy icon in greeter
  + Drop faces images
  + Updated translations
- Changes from version 2.91.93:
  + Fall back to username in user list if user doesn't have real
    name configured.
  + Be more robust against unexpected changes from accounts
    service
  + Move some custom widgets to builder file out of source code.
  + Load accounts settings before showing session selector.
  + Fix crash for passwordless login
  + Other misc fixes
- Changes from version 2.91.92:
  + dconf overrides db generation clean ups
  + ensure accounts service account is loaded before login
  + slightly change hue of fg color
  + maintain worker environment solely in PAM
- Changes from to version 2.91.91:
  + Fix bug that some times prevent user list from coming up
- Changes from version 2.91.90:
  + Make better use of iso-codes
  + Fix g-s-d lockdown
  + Set SIGPIPE to default before starting session
  + Fix disconnect button for XDMCP connections
  + GTK 3 fixes
  + Add back session chooser
  + Move greeter to accounts service library
  + Update dconf defaults to reflect new schema names
- Changes from version 2.91.6:
  + Add dconf profile
  + Move to gtk3
  + Apply a thick layer of gnome 3 textured paint
  + Move from ~/.dmrc to accounts service
  + Be more robust against missing icons
- Changes from version 2.91.4:
  + Omit version in login window if unknown
  + Fix version display when release file is empty
  + User manager async fixes
  + Add greeter specific dconf database for lockdown
  + XDMCP/ipv6 fix
  + Fix to make sure PostSession is always called when appropriate
  + Only automatically login on boot when autologin is enabled,
    not after logout
  + Enable braille reader support when screenreading is enabled
  + Beep when login window is ready
  + Make beeps audible by enable event sounds
- Add libattr-devel, pkgconfig(accountsservice) BuildRequires.
- Add dconf, gnome-session-core BuildRequires, needed for directory
  ownership.
- Drop gdm-focus-user-chooser.patch, gdm-xdmcp-disconnect.patch,
  gdm-autologin-once.patch: fixed upstream.
- Remove gnome-themes Requires: not needed anymore.
- Remove gnome-applets-gdm package (the applet was removed) and add
  Provides/Obsoletes for it.
- Adapt gnome-settings-daemon directory path in configure call
  since we changed it for GNOME 3.
- Disable gdm-greeter-greater-ui.patch: the patch needs to be
  rebased. See bnc#689552.
- Rebase patches:
  + gdm-desktop-session-env-pam.patch
  + gdm-helper-directory.patch
  + gdm-passwordless-login.patch
  + gdm-plymouth.patch
  + gdm-selecting-desktop-environment.patch
  + gdm-vt-allocation-hack.patch
* Tue Feb 15 2011 vuntz@opensuse.org
- Add gdm-xdmcp-disconnect.patch: the Disconnect option should tell
  the gdm daemon to disconnect, instead of just making the greeter
  exit. And the daemon should exit. Taken from git. Fix bnc#669392.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Jan 14 2011 vuntz@opensuse.org
- Rebase gdm-vt-allocation-hack.patch to actually apply.
- Apply gdm-vt-allocation-hack.patch on 11.4 and later again: the
  topic needs more discussion, and without the hack, on a default
  boot, a mingetty instance will receive all the input from Xorg.
  This is because Xorg will start on tty2 and a mingetty will also
  start there, because of the sysvinit configration. This is
  extremely bad, since this means everything the user types will
  lead to login attemps in mingetty.
- Add gnome-power-manager and iso-codes Recommends: they are both
  improving the gdm experience, but are not mandatory.
* Tue Jan 11 2011 vuntz@opensuse.org
- Add gdm-focus-user-chooser.patch: correctly give the focus to the
  user chooser on startup. Fix bnc#652938.
* Thu Dec 16 2010 vuntz@opensuse.org
- Add gdm-plymouth-X-nr.patch to start Xorg with -nr instead of the
  non-existing "-background none". Thanks to Kay Sievers!
* Wed Dec 15 2010 vuntz@opensuse.org
- Only apply gdm-vt-allocation-hack.patch on openSUSE 11.3 and
  earlier: with 11.4, we have a recent-enough version of Xorg that
  does this magic for us. Thanks to Kay Sievers for the hint!
- Add gdm-plymouth.patch: this patch adds support for a nice
  transition from plymouth. Taken from Fedora.
* Fri Oct  8 2010 vuntz@opensuse.org
- Rework the way we handle passwordless logins:
  + Stop using SuSEconfig for this. Since this is the last thing
    that was done in SuSEconfig.gdm, drop SuSEconfig.gdm.
  + Add gdm-passwordless-login.patch: we now directly look at the
    DISPLAYMANAGER_PASSWORD_LESS_LOGIN option in
    /etc/sysconfig/displaymanager, and use the gdm-autologin pam
    service for authentication when we want passwordless logins.
  + On upgrades, we make sure that /etc/pam.d/gdm does not contain
    the old way to handle DISPLAYMANAGER_PASSWORD_LESS_LOGIN: if
    /sbin/conf.d/SuSEconfig.gdm exists and if /etc/pam.d/gdm
    contains pam_permit.so, then we have an old package which used
    the old way. We move /etc/pam.d/gdm to /etc/pam.d/gdm.rpmold to
    make sure we get back the right pam configuration.
- Update gdm-domain-logon.patch a bit: even though it's not
  applied because the patch needs to be rebased, a few things could
  be cleaned up. The most visible part is that we prefix the
  configuration key with SUSE to clearly show it's SUSE-specific.
- Update gdm-sysconfig-settings.patch a tiny bit to make
  gdm-passwordless-login.patch easier.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Mon Sep 27 2010 aj@suse.de
- Mark /var/run/gdm as ghost in case that /var/run is on tmpfs.
  gdm creates the directory itself.
* Wed Sep 22 2010 vuntz@opensuse.org
- Rename gdm-2.21.9-no-fatal-warnings.patch to
  gdm-is-not-unstable-unless.patch, and change the behavior:
  if the SUSE_ENABLE_UNSTABLE_CHECK environment variable is set, we
  just do like upstream. If it is not set, we make GDM assume it's
  not running a development version, which disables fatal warnings
  and verbose logs.
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Change orca invocation to work better with latest release
  + Fix "Other..." item in network-login-only scenarios
  + Move gdm.schemas to pkgdatadir
  + XDMCP fixes
  + Improve ordering of languages in languages list
  + Make various slow calls that blocked before asynchronous
  + Fix up dbus security policy
  + Various other fixes
  + Translation updates
- Drop gdm-fix-dbus-properties.patch: fixed upstream.
* Mon Sep 13 2010 vuntz@opensuse.org
- Add gdm-fix-dbus-properties.patch: org.gnome.DBus.Properties was
  referenced instead of org.freedesktop.DBus.Properties in the dbus
  configuration. Fix bnc#633655.
- Move fast-user-switch-applet Obsoletes to gnome-applets-gdm and
  add a Provides there too: the applet is really the old
  fast-user-switch-applet applet.
* Wed Aug 18 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Port to upower
  + Don't stomp on $LANGUAGE environment variable
  + Don't show markup in UI
  + Fix cancel button
  + Reask user for password a few times, before failing
  + Load users asynchronously
  + Handle EINTR on getpw* calls
  + Translation updates
- Replace DeviceKit-power-devel BuildRequires with
  libupower-glib-devel.
* Sun Aug  8 2010 vuntz@opensuse.org
- Cleanup update to 2.31.2, based on the 2.30.4 package I did for
  GNOME:STABLE:2.30.
- Drop gdm-save-panel-space-on-low-resolutions.patch: fixed
  upstream, in a different way.
- Drop gdm-add-missing-locale.patch: the file is now in the
  tarball.
- Update gdm-default-wm.patch after code change.
- Rebase gdm-greeter-greater-ui.patch.
* Fri Jul 30 2010 dimstar@opensuse.org
- Update to version 2.31.2:
  + Add support for legacy "custom" session name
  + XDMCP fixes
  + Add optional support for account service
  + Gracefully hide control center from user switch menu if not
    available
  + Revert metacity focus workaround, now that metacity is fixed
  + Rehide g-p-m context menu
  + Updates to work better with newer icon theme
  + Show username input box when there's no local user
  + Remove gdm-restart and gdm-stop scripts
  + Remove text labels from option menus
  + Various user manager and user chooser fixes and performance
    enhancements
  + Escape names before showing markup
  + Call button "unlock" not "login" when user is already logged
    in
  + Cap how long ck-history is allowed to run and how far back its
    allowed to go
  + Improvements to the way users are sorted
  + Ensure slave's children always die with the slave
  + Use lsb_release if available to determine system description
  + Automatically retry on login failure
  + Fix timed login + disable-user-list together
  + Don't exit when X fails to start
  + Trap XAddHosts call
  + Minor fixes in screenshot tool
  + Halectomy of the last remnants of hal
  + Various crasher fixes
  + Various memory leaks
  + Various build and warning fixes
- Changes from version 2.31.1:
  + bgo#594818: Now GDM saves its GConf settings per-seat.
  + Improvements so compiling with -DGSEAL_ENABLE works better.
  + Use g_remove() to remove directories instead of g_unlink().
  + Other bugs fixed: bgo#617661, bgo#576801, bgo#609272,
    bgo#591937
- Rebase gdm-vt-allocation-hack.patch to apply without fuzz.
- Rebase gdm-xauthlocalhostname.patch.
- Mark gdm-domain-logon.patch as needing a rebase: it's a SLED
  patch that is intrusive, so we'll see if someone rebases it.
  Comment out gnome-patch-translation-prepare and
  gnome-patch-translation-update calls since this patch was the one
  introducing strings.
- Drop gdm-polkit-gnome-path.patch: fixed upstream with a
  configure option that we already passed
  (--with-polkit-gnome-directory).
- Drop gdm-xdmcp-uninitialized.patch: fixed upstream.
- Drop gdm-greeter-no-local-user.patch: fixed upstream.
* Tue Jun 22 2010 vuntz@opensuse.org
- Add gdm-greeter-no-local-user.patch to fix the greeter to work
  when there's no local user on the machine; this is useful with
  NIS for example. Fix bnc#615044; the patch was committed
  upstream.
* Thu Jun 17 2010 captain.magnus@opensuse.org
- Add gdm-xdmcp-uninitialized.patch to fix an uninitialized
  variable, which caused XDMCP to fail way too often. Patch taken
  from upstream git.
* Thu Jun 17 2010 vuntz@opensuse.org
- Update gdm-greeter-greater-ui.patch: we didn't rebase it earlier,
  and lost our improved UI.
* Mon May 24 2010 guido+opensuse.org@berhoerster.name
- Fixed filelist
* Mon May 24 2010 guido+opensuse.org@berhoerster.name
- Split off gnome-applets-gdm
* Sun May 23 2010 guido+opensuse.org@berhoerster.name
- Depend on gnome-session-core rather than gnome-session
* Thu May  6 2010 captain.magnus@opensuse.org
- Update to version 2.30.2:
  + Accessibility is now enabled by default for the GDM login
    screen
  + When the face browser is disabled, the PAM conversation is
    started immediately, so users do not need to click a button to
    start entering the username and password. bgo#591082
  + Add label-for and labelled-by a11y relations to the entry field
    in the login GUI. This makes the login GUI more accessible when
    using AT programs. bgo#613434
  + Fixed bugs that were causing XDMCP to not show the greeter
    again after logout. bgo#606724
  + The default XDMCP PingIntervalSeconds was increased from 15 to
    60 seconds
  + The WINDOWPATH environment variable is now set for the user
    session. bgo#609272
  + Ensure Init script is called when using Automatic Login.
    bgo#614488
  + Fix race condition with Timed Login. bgo#614062
  + Drop xhost localuser:gdm and localuser:root when the user
    session starts. bgo#605350
  + Removed the icon monitor from the GDM login GUI since it was
    not functional and was causing problems with automounting
    user's HOME directories. #609321
  + Do not mark "%%x" for translation. bgo#613306
  + Remove duplicated strings for translation. bgo#609179
  + Minor doc corrections
  + Translation updates
- gdm-greeter-greater-ui.patch does not apply and is commented out
  temporarily
- Respin gdm-xauthlocalhostname.patch for fuzz=0
- Respin gdm-polkit-gnome-path.patch
* Thu Apr  8 2010 vuntz@opensuse.org
- Use the path for the at-spi-registryd from the old at-spi stack:
  the at-spi2 developers think it's safer to ship 11.3 with the old
  stack by default.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Sun Mar 28 2010 vuntz@opensuse.org
- Call /etc/X11/xdm/Xstartup from /etc/gdm/PreSession/Default
  instead of from /etc/gdm/Xsession. This should fix some
  permission issue. Fix bnc#573669.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + The greeter is not torn down until pam_open_session finishes
    since some PAM modules can ask questions up until this point.
  + bgo#607738: The daemon now kills the session process rather
    than the entire process group.  The corresponding gnome-session
    bug bgo#607658 is released with 2.29.92 so this works properly.
- Rebase gdm-polkit-gnome-path.patch.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.29.6:
  + Various build fixes
  + Crash fix in layout detection
  + Crash fix in session list detection
  + Remove timeout for interacting with PAM
  + Fix compile with --no-as-needed
  + Add debug message if system lacks fonts
  + Disable switch user item if user switching won't work
- Rebase gdm-selinux.patch.
* Sun Jan 17 2010 vuntz@opensuse.org
- Update gdm-sysconfig-settings.patch:
  + support DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN for
    security/DisallowTCP in gdm.conf
  + support DISPLAYMANAGER_REMOTE_ACCESS for xdmcp/Enable in
    gdm.conf
  + do not pretend we got a value from sysconfig if we didn't get a
    result (we were returning TRUE too easily from
    gdm_settings_system_backend_get_value()
  + make sure that, when saving the configuration, we put the right
    value if it wasn't supposed to be changed (before, we used to
    put whatever we had in memory, which was never initialized to
    the right values, so random data)
  + add a note to gdm.conf about the fact that
    /etc/sysconfig/displaymanager is used
- Remove the parts of SuSEconfig.gdm that were dealing with
  updating gdm.conf, since gdm-sysconfig-settings.patch make gdm
  poke directly in sysconfig. SuSEconfig.gdm is still needed for
  the DISPLAYMANAGER_PASSWORD_LESS_LOGIN option, though.
- Rebase gdm-domain-logon.patch, and only show the domain chooser
  if DISPLAYMANAGER_AD_INTEGRATION is set in sysconfig.
- Reenable gnome-patch-translation support, since
  gdm-domain-logon.patch is applied again.
- This means we can remove /etc/gdm/gdm_sysconfig.conf from the
  package.
- Remove sysconfig.displaymanager-gdm source: this has not been
  used for a long time.
* Sat Jan 16 2010 vuntz@opensuse.org
- Remove libglade2-devel BuildRequires.
- Also remove hal-devel BuildRequires which was added for the
  gdm-keyboard-from-hal.patch (removed now).
- Redo gdm-suse-xsession.patch in a way that won't require further
  updates when upstream files change (which is something we can
  ignore).
- Rebase gdm-greeter-greater-ui.patch.
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + XDMCP fixes on Solaris
  + run PostLogin script as user instead of gdm
  + Fix ellipses usage on User Switch Applet
  + Add ability to customize system language list
  + Solaris NULL printf fixes
  + Convert from glade to gtkbuilder
  + Detect default keyboard layout better
  + Ignore executable subfolders of xinitrc.d
  + Don't reveal valid usernames when authenticating
- Respin gdm-suse-xsession.patch
- Remove gdm-keyboard-from-hal.patch: fixed upstream another way.
- Disable gdm-greeter-greater-ui.patch: it needs to be rebased.
- Update gdm-default-wm.patch to apply without fuzz.
- Add gdm-add-missing-locale.patch. Patch taken from upstream and
  can be removed with the next version update
* Thu Dec 24 2009 vuntz@opensuse.org
- Add hal-devel BuildRequires to fix build.
* Tue Dec 22 2009 vuntz@opensuse.org
- Update to version 2.29.4:
  + Remove deprecated function g_mapped_file_free
  + Fix option widgets to work better with orca
  + Make --with-custom-conf work
  + Don't hard code path to policykit agent
  + Don't backup xkb configuration before login
- Update gdm-helper-directory.patch: some part is now fixed
  upstream, and we also need to set the right path for the
  polkit-gnome agent.
- Pass --with-polkit-gnome-directory to configure.
- Update gdm-selinux.patch to apply without fuzz.
* Thu Dec  3 2009 vuntz@opensuse.org
- Update to version 2.29.1:
  + A new desktop extension is now supported in GDM session desktop
    files (normally found in /usr/share/xsessions). Setting the
    X-GDM_BypassXsession key to true (X-GDM_BypassXsession=true)
    will cause the Xsession script to not be used to launch the
    session. This can be useful if you want to create a "failsafe"
    xterm session.
  + Fix makedist problem.
- Changes from version 2.29.0:
  + Now GDM supports Include, Exclude, and IncludeAll configuration
    options to allow the ability to configure which users are
    displayed in the FaceBrowser.
  + Now GDM supports better debugging.  Users can set the
    debug/Enable configuration option to turn on GDM debugging.
  + The directory where GDM screenshots are placed has been moved
    to its own directory: /var/run/gdm/greeter/GDM-Screenshot.png.
    The screenshot directory can now be specified at build time via
    the --with-screenshot-dir configure argument.
  + Many simple-greeter Face Browser usability improvements.
  + The simple-greeter Face Browser tree view search entry is now
    obscured to help prevent accidental display of passwords.
  + Shutdown and reboot functions are moved to a menu in the
    simple-greeter panel instead of being presented as buttons.
    The shutdown menu is better positioned on multi-monitor
    displays.
  + The simple-greeter panel notification area has been improved
    and now honors the GConf setting for
    /apps/notification_area_applet/prefs/padding.
  + The entry field in the simple-greeter now has accessibility
    labels so it will work better with accessibility programs.
  + The clock in the simple-greeter panel no longer shows the date,
    making the screen look a little cleaner. The date is moved to
    the clock tooltip so it is still available.
  + The simple-greeter now uses gethostname instead of
    g_get_host_name since it is more reliable when the hostname
    changes at runtime.
  + The user switch applet now honors disable_lock_screen.  The
    option to lock screen is now not shown if disable_lock_screen
    is set.
  + The /var/run/gdm directory is better locked down.
  + GDM no longer crashes on bad UTF-8 in the /etc/passwd file.
  + When the worker dies, the auth-failed signal is no longer sent.
    This prevents a crash that happens when switching run-levels
    when the login screen is displayed.
  + Ensure that the length of sockaddr structure is set to the
    correct length for IPv4 or IPv6. This makes GDM work better on
    some operating systems that are picky about the length being exact.
  + String and documentation improvements.
- Changes from version 2.28.1:
  + GDM will now avoid calling XAddHosts for remote connections.
    Refer to bgo#598142 for more information.
  + Now GDM uses DeviceKit-power instead of gnome-power-manager for
    Suspend support.
  + Now the at-spi-registryd-wrapper.desktop GDM autostart file
    will run at-spi-registryd directly instead of calling
    at-spi-registryd-wrapper.
  + Fix to the visibility check for the "Other" button which
    corrects some situations where the button would not appear when
    it was supposed to.
  + Now the GDM daemon will make the /var/log/gdm directory if it
    does not exist.
  + Fixes to avoid autologin failure when a NULL username is passed
    in.
  + Restore CTYPE when canonicalizing codesets.
  + Several fixes to avoid warnings.
- Change default permissions of /var/run/gdm from 755 to 751
  (upstream moved to 711).
- Rebase gdm-helper-directory.patch to apply without fuzz, and add
  a fix from upstream to really use the right at-spi-registryd
  directory.
- Rebase gdm-greeter-greater-ui.patch.
- Rebase gdm-save-panel-space-on-low-resolutions.patch, and also
  tweak it a bit because the size of the clock label has been
  reduced.
- Drop gdm-build-fixes.patch: fixed upstream.
- Drop gdm-devkit-power.patch: fixed upstream.
- Drop gdm-keyboard-from-sysconfig.patch: this is needed for
  openSUSE <= 11.1, but DeviceKit-power is now required by gdm and
  won't work on such versions of openSUSE.
* Tue Oct 20 2009 vuntz@opensuse.org
- Add gdm-look-at-runlevel.patch to work around issue where gdm
  blocks the restart/shutdown process because of a race there.
  Should fix bnc#540482.
- Version the Provides/Obsoletes to fix a rpmlint warning.
- Reorder packageand() arguments for the branding supplements to
  fix rpmlint warning.
* Fri Oct  2 2009 vuntz@opensuse.org
- Add gdm-devkit-power.patch: gdm was using a dbus API which
  doesn't exist anymore, and the right way to handle this is to use
  DeviceKit-power.
- Add DeviceKit-power-devel BuildRequires for the patch.
- Add gdm-polkit-gnome-path.patch to use the correct path for the
  polkit agent.
- Rebase gdm-greeter-greater-ui.patch. Fix bnc#533597.
* Fri Oct  2 2009 vuntz@opensuse.org
- Make sure to package /var/cache/gdm: without it, gdm doesn't use
  the configured language/layout for the user.
* Thu Oct  1 2009 vuntz@opensuse.org
- Add gdm-autologin-once.patch: we don't want to autologin again
  after a logout. Fix bnc#532090.
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 2.28.0:
  + GDM supports the ability to specify the automatic/timed login
    user via a script via the same interface that the old GDM
    supported.
  + The user's dmrc and face image files are stored in
    /var/cache/gdm, so that the login process does not need to
    access the user's $HOME directory before authentication. Refer
    to bgo#565151.
  + Fix the login GUI options widget so the language/session/layout
    choices are not reset after a failed login.
  + Fix language dialog so it does not crash if the user click's
    the "OK" button when no language is selected.
  + Fix to ensure that the login dialog regains focus after the
    language or layout dialogs are used.
  + The language dialog has improved logic to sort the language
    names more correctly.
  + Make sure to check error variable is not NULL before
    referencing it in the gdm-user-manager code.
  + Make sure to not print NULL strings since this causes crashes
    on some platforms.
  + Improve documentation.
- Add gdm-build-fixes.patch to fix build.
* Mon Sep 28 2009 vuntz@opensuse.org
- Add gdm-xauthlocalhostname.patch: fix non-working user session
  when the hostname changes during login. Fix shipstopper
  bnc#538064.
- Add gdm-default-wm.patch: gdm now reads the DEFAULT_WM setting in
  /etc/sysconfig/windowmanager to know which session to use by
  default instead of always using GNOME.
  This should fix using GDM for XFCE.
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 2.27.90:
  + Autostart polkit-gnome authentication agent.
  + Add screen capture sound effect to screenshot tool.
  + If HOST_NAME_MAX is not available, try _POSIX_HOST_NAME_MAX,
    then default to 256.
  + Add users "nobody4" and "noaccess" to the list of users to
    filter from the Face Browser.
  + Add Solaris logindevperm support.
  + Fix mispelling of XDMCP.
  + Improve documentation.
- Add libcanberra-devel BuildRequires.
* Thu Aug  6 2009 vuntz@novell.com
- Remove old cleanup instructions for /var/lib/gdm/*.log* in pre.
- Do not try to grep /sbin/conf.d/SuSEconfig.gdm in pre, if the
  file doesn't exist. Fix bnc#508511.
* Fri Jul 31 2009 vuntz@novell.com
- Correctly comment out patch that needs rebasing.
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- Update to version 2.27.4:
  + Favor XFree86 Xinerama over Solaris Xinerama on Solaris
  + Make greeter a well behaved session client
  + XDMCP fixes
  + Fix up btmp record handling
  + Handle locales with modifiers better
  + Use better logic with keyboard layout handling
  + Change example PAM file/documentation to demonstrate
    password-less login
  + Handle usernames from non-utf8 locales
  + Allow dbus introspection for gdm services
  + Show more details authentication error messages in UI
  + Allow uppercase and lowercase booleans in config file
  + Be more consistent with booleans in schemas
  + Use g_timeout_add_seconds to reduce wakeups
  + Make greeter window more clear when user list is disabled
  + Put greeter login window in same ctrl-alt-tab menu as panel
  + Port greeter to PolicyKit 1.0
  + Shave off 1/2 second delay when bringing up greeter
  + OS X portability fixes
  + Look for locales in /usr/lib/locale instead of /usr/share/locale
  + Better handling when two users have the same name
- Drop upstreamed patches:
  + gdm-session-worker-check-states.patch
  + gdm-fix-locale-listing.patch
  + gdm-dbus-allow-introspection.patch
  + gdm-keyboard-invalid-user-data.patch
  + gdm-proper-session-handling.patch
  + gdm-accreditation-failed-log.patch
  + gdm-hide-lonely-other.patch
- Rebased patches:
  + gdm-suse-xsession.patch
  + gdm-keyboard-from-hal.patch
- Disables patches (need rebasing)
  + gdm-domain-logon.patch
- Clean %%%%files section from duplicates
- Drop dependency to PolicyKit-devel
* Mon Jun 15 2009 vuntz@novell.com
- Update gdm-keyboard-invalid-user-data.patch to the patch that was
  committed to git (fix a bug where layouts with variant were
  considered invalid).
* Sun Jun 14 2009 vuntz@novell.com
- Add gdm-proper-session-handling.patch to fix bnc#506040:
  correctly handle the end of session, to not show an error dialog.
* Tue Jun  9 2009 vuntz@novell.com
- Update gdm-keyboard-from-sysconfig.patch: we correctly interpret
  the keyboard layout specified in sysconfig thanks to a map file
  from sax that we use to convert the layout name to a X layout.
- Add gdm-keyboard-invalid-user-data.patch: the old gdm was not
  setting a valid keyboard layout in some cases, and this invalid
  layout ended up in ~/.dmrc. This patch makes gdm detect this and
  revert the user data to the default layout.
* Fri May 15 2009 vuntz@novell.com
- Add gdm-keyboard-from-hal.patch to read the default keyboard
  layout from hal on 11.2, should fix bnc#478083 and bnc#492284.
- Split the keyboard part of gdm-sysconfig-settings.patch in
  gdm-keyboard-from-sysconfig.patch, and only applit on 11.1 and
  earlier. Also update the patch to strip some console keymaps part
  of the layout that won't work in X (eg, fr-latin1 -> fr).
- Based on work from claes.backstrom@fsfe.org and hpj@novell.com.
* Tue May 12 2009 vuntz@novell.com
- Drop gdm-X_SERVER.patch: it's not needed anymore since
  /usr/bin/Xorg is the only supported X now.
- Add gdm-helper-directory.patch to replace
  gdm-2.23.92-gsd-path.patch and
  gdm-consolekit-helper-subdir.patch: this new patch should be
  suitable for upstream inclusion. Pass
  - -with-gnome-settings-daemon-directory and
  - -with-consolekit-directory to configure.
- Tag gdm-2.21.9-no-fatal-warnings.patch,
  gdm-vt-allocation-hack.patch, gdm-domain-logon.patch,
  gdm-selinux.patch.
* Mon Apr 20 2009 vuntz@novell.com
- Update to version 2.26.1:
  + Use O_APPEND when opening log files
  + Don't depend on gnome-power-manager registering with session
    manager - Give greeter and slave access to the display even
    after the hostname changes
  + Give greeter and slave access to display independent of
    hostname
  + Clean up stale auth temporary directories
  + Fix double free crasher in user switcher applet
  + Load saved settings after user types username into Other box
  + Pass environment to PAM worker processes so messages are
    localized
  + Fix up auditing for Solaris auditor
- Drop gdm-xauthlocalhostname.patch: fixed another way upstream.
- Drop gdm-propagate-env-to-jobs.patch: fixed upstream.
* Fri Mar 27 2009 vuntz@novell.com
- Use pwdutils for PreReq instead of directly listing the programs.
* Mon Mar 16 2009 mboman@suse.de
- Update to version 2.26.0:
  + Make xdmcp/PingIntervalSeconds config option work
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Mar 13 2009 mboman@suse.de
- Update to version 2.25.92:
  + Hide presence features in user switcher applet
  + Make autologin happen more than once after bootup
  + Better panel placement and login screen sizing in
    multihead set ups
  + Fix XDMCP and add more XDMCP configurability
  + Rework dbus security files to be more correct
  + Various other fixes
- Remove gdm-login-window-size.patch. Fixed upstream
- Remove gdm-bnc468374-dbus-send-dest.patch. Fixed upstream
- Update gdm-save-panel-space-on-low-resolutions.patch
- Update gdm-suse-xsession.patch
- Remove BuildRequires gnome-common, scrollkeeper
- Remove custom CFLAGS
* Thu Mar  5 2009 vuntz@novell.com
- Add gdm-gconf-path.patch: the system-wide changes done in gconf
  are not in gconf.xml.system, but gconf.xml.defaults.
* Mon Feb 23 2009 vuntz@novell.com
- Update gdm-domain-logon.patch: add new files in POTFILES.in.
  Thanks to Stanislav Brabec for spotting this!
* Thu Feb 19 2009 vuntz@novell.com
- Add gdm-dbus-allow-introspection.patch to allow dbus
  introspection for the services. Patch by Timo Hoenig. Fix
  bnc#473880.
- Use gnome-patch-translation for strings in
  gdm-domain-logon.patch. Fix bnc#440860.
* Sat Jan 31 2009 vuntz@novell.com
- Add gdm-fix-locale-listing.patch: correctly list all locales so
  that they appear in the language chooser. Fix bnc#446446.
* Sat Jan 31 2009 vuntz@novell.com
- Add gdm-propagate-env-to-jobs.patch: forward the environment to
  gdm-session-worker to have translated PAM messages. Fix
  bnc#440860.
* Sat Jan 31 2009 vuntz@novell.com
- Drop unneeded BuildRequires: docbook_4
- Remove check for old versions of openSUSE
- Don't pass non-existing --enable-secureremote flag to configure
* Fri Jan 30 2009 vuntz@novell.com
- Add gdm-session-worker-check-states.patch to fix bnc#470714. We
  were handling late a setup signal, while we were already doing
  something else.
* Thu Jan 29 2009 vuntz@novell.com
- Add gdm-accreditation-failed-log.patch to improve logging in the
  case of accreditation failure.
* Wed Jan 28 2009 vuntz@novell.com
- Add gdm-login-window-size.patch to fix the login window size: the
  width could be too small in various cases (eg, some pam
  messages). Also needed for gdm-hide-lonely-other.patch.
- Add gdm-hide-lonely-other.patch to hide the Other item in the
  user list in relevant cases, especially when we disable the user
  list. Fix bnc#439894.
* Tue Jan 27 2009 vuntz@novell.com
- Manual merge with GNOME:Factory:Next.
- Drop gdm-fix-xdmcp.patch: fixed another way upstream.
- Add gdm-bnc468374-dbus-send-dest.patch to add send_destination in
  the dbus policy. Fix bnc#468374.
* Thu Jan 22 2009 mxwu@novell.com
- Add gdm-selecting-desktop-environment.patch to select right
  desktop environment (bnc#460691)
* Mon Jan 12 2009 mauro@suse.de
- Translations update.
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.25.2:
  + Fix focus issues in applet
  + Use text view instead of entry
  + Add support for a real automatic login
  + Redesign user switch applet
  + Make XDMCP work again
  + Add a bevel around the dialog
  + Remove capslock warning label
- Remove gdm-2.23.92-another-locale-fixup.patch. Fixed upstream
- Remove gdm-2.23.92-filter-dupes-from-lang-list.patch. Fixed upstream
- Remove gdm-2.23.92-fix-crash.patch. Fixed upstream.
- Remove gdm-fix-icon-scale.patch. Fixed upstream
- Remove gdm-autologin.patch. Fixed upstream
- Remove gdm-fix-pam-auditing.patch. Fixed upstream
- Comment out gdm-greeter-greater-ui.patch. Patch does not apply
  due to massive changes in glade file. Needs to be redone completly.
* Fri Dec  5 2008 hpj@novell.com
- Update gdm-domain-logon.patch to omit undesirable domains
  (bnc#450143).
* Wed Dec  3 2008 hpj@novell.com
- Replace gdm-2.21.5-vt7-temporary-hack.patch with
  gdm-vt-allocation-hack.patch. The new patch doesn't hardcode gdm
  to VT7, but instead scans for a free VT starting with VT7
  (bnc#434598).
* Mon Dec  1 2008 hpj@novell.com
- Update gdm-sysconfig-settings.patch to translate the name of the
  configured system keymap into something libxklavier can
  understand (bnc#446958).
* Mon Dec  1 2008 hpj@novell.com
- Update gdm-domain-logon.patch to make domain prefix logon work
  when entering user names manually (bnc#450146).
* Sun Nov 30 2008 hpj@novell.com
- Add gdm-save-panel-space-on-low-resolutions.patch (bnc#449815).
* Fri Nov 21 2008 hpj@novell.com
- Add gdm-always-reflect-keyboard-layout.patch (bnc#438159).
* Thu Nov 20 2008 hpj@novell.com
- Add gdm-fix-xdmcp.patch, which makes XDMCP work (bnc#441396).
- Add gdm-fix-pam-auditing.patch, which makes PAM auditing work
  as expected on logout (bnc#436852).
* Wed Nov 12 2008 hpj@novell.com
- Update gdm-sysconfig-settings.patch, removing debug spew.
* Wed Nov 12 2008 vuntz@novell.com
- Add gdm-greeter-greater-ui.patch to improve the layout of the
  greeter. End of bnc#436431.
* Tue Nov 11 2008 hpj@novell.com
- Update gdm-sysconfig-settings.patch, fixing bnc#440863.
* Sun Nov  9 2008 jpr@novell.com
- Add gdm-autologin.patch so the greeter is not created for
  autologin and improve startup time (bnc#436524)
- Update gdm-domain-login.patch so the domain box is present
  even if the user list is not (bnc#431339)
* Fri Nov  7 2008 vuntz@novell.com
- Merge hpj's submission: Add gdm-sysconfig-settings.patch, which
  fixes bnc#432360.
* Thu Nov  6 2008 vuntz@novell.com
- Add gdm-fix-icon-scale.patch: make icons in the greeter use a
  reasonable size. Part of bnc#436431.
* Tue Nov  4 2008 jpr@novell.com
- Add requires for ConsoleKit-x11, gnome-session
  (bnc#441105, bnc#428294)
- Add recommends for gnome-settings-daemon, its very useful to have
* Mon Nov  3 2008 jpr@novell.com
- Add iso-codes-devel to the build requires so the languages can
  be found (bnc #435157)
- Add gdm-2.23.92-filter-dupes-from-lang-list.patch to prevent
  listing languages more that once in the selector
- Add gdm-2.23.92-fix-crash.patch to prevent crash when selecting
  drop down items like language
- Add gdm-2.23.92-another-locale-fixup.patch to use canonical system
  locale info
- Refresh gdm-suse-xsession.patch to have a shell to run with and
  don't call anything else after our the xorg Xsession runs.
* Sun Nov  2 2008 hpj@novell.com
- Update gdm-domain-logon.patch again, fixing bnc#439892.
* Thu Oct 16 2008 hpj@novell.com
- Update gdm-domain-logon.patch, removing some dead code and a
  signal callback that is no longer being used.
* Thu Oct  9 2008 hpj@novell.com
- Replace gdm-2.23.92-host-wild.patch with
  gdm-xauthlocalhostname.patch. The new patch sets the
  XAUTHLOCALHOSTNAME env var instead of setting the cookie's
  family to FamilyWild.
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Fri Oct  3 2008 mboman@suse.de
- Update to version 2.24.0:
  + Allow the build to succeed without a gdm user
  + Use Bourne shell syntax in Xsession.solaris
  + Set ownership of .gconf.mandatory
  + Translation updates
* Fri Sep 26 2008 hpj@novell.com
- Add gdm-domain-logon.patch, which implements an Active Directory
  domain logon selector using wbinfo.
* Sat Sep 20 2008 vuntz@novell.com
- Add gdm-suse-xsession.patch, which is similar to the
  gdm-xdm-sessions.patch we have with GDM <= 2.20: it makes GDM
  use the openSUSE scripts in /etc/X11/xdm, for proper integration.
- Add gdm-desktop-session-env-pam.patch, that sets the
  DESKTOP_SESSION environment variable for pam. The goal is to let
  the gnome-keyring pam module know when GNOME will be used, so
  that it knows if it should start gnome-keyring.
- This is part of bnc#427744.
* Fri Sep 12 2008 jpr@novell.com
- Move gdm-2.23.92-set-xauthlocalhostname-when-local.patch to
  gdm-2.23.92-host-wild.patch to really fix race (bnc #420057)
- Update gdm-consolekit-helper-subdir.patch, it was using gdm's
  LIBEXECDIR, not ConsoleKit's
- Use correct at-spi dir config option
* Thu Sep 11 2008 jpr@novell.com
- Update to version 2.23.92:
  * Fix selection handling in language and layout choosers
  * Fixed bgo#545337, grey screen on login
  * Start g-s-d correctly
  * Add missing WM desktop file
  * Add docs
  * Make set-show-user* into construct properties
  * Revert the larger greeter font size
  * Add slave log file
  * Fix up some log rotation problems
  * Translations
- Set permissions on gconf files in /var/lib/gdm so gdm user can
  read them
- Point to the correct location for gnome-settings-daemon when
  starting the greeter session with gdm-2.23.92-gsd-path.path
- Use the suse standard libexecdir
- Remove gdm-libwrap.patch, the issue was solved upstream
- Remove resmgr from pam files (bnc#422615)
- Obsolete fast-user-switch-applet, the applet was merged into gdm
- Add gdm-2.23.92-set-xauthlocalhostname-when-local.patch to fix
  race when host name changes at start up (bnc #420057)
* Fri Aug 22 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Wed Aug 20 2008 sbrabec@suse.cz
- Updated to version 2.23.2:
  * Requires ConsoleKit 0.3.0
  * Keyboard layout selection from greeter
  * Save backup of ~/.xsession-errors
  * Add a GConf key for not showing the user list
  * Now support PostLogin, PreSession, and PostSession hooks
  * Add DisallowTCP back
  * Support PAM_XDISPLAY and PAM_XAUTHDATA
  * Add lang tags, to help Pango pick the right font
  * Set the initial user selection correctly
  * Add frame around user icons and make them larger
  * Write gdm screenshot output to /var/run/gdm instead of /tmp
  * Save one old copy of greeter log file
  * Set a minimum width for the login window
  * Fix check for /etc/gdm/Init/Default so it will actually be
    executed
  * Wait for ready from backend when cancelling from greeter
  * Use per session directories in /var/run/gdm for xauth databases
  * Move ConsoleKit registration into the worker
* Fri Aug 15 2008 maw@suse.de
- Fix the build on biarch platforms by listing files that end
  up in /usr/lib64 correctly
- Remove the empty %%post section
- Mark several files as config files.
* Fri Aug  1 2008 hpj@suse.de
- Major upgrade to GDM 2.22.0, which is pretty much a complete rewrite upstream:
  + Added gdm-consolekit-helper-subdir.patch, which lets GDM find ConsoleKit's
    helper executable in the subdir where it's installed.
  + Added gdm-2.21.9-no-fatal-warnings.patch, which prevents GDM from crashing
    on non-fatal errors.
  + Added gdm-greeter-file-system-type-can-be-null.patch, which prevents a
    crash.
  + Added gdm-2.21.5-vt7-temporary-hack.patch, which makes GDM default to VT7
    when the initial VT is not specified. Prevents a keyboard lockup on startup.
  + Dropped patches:
    gdm-conf.patch,                    gdm-language-dialog-size.patch,
    gdm-xdm-sessions.patch,            gdm-presession-kde-path.patch,
    gdm-gdmsetup-rootonly.patch,       gdm-2.8.0.0-any-hostname-auth.patch,
    gdm-2.8.0.0-list-users.patch,      gdm-2.8.0.0-setup-no-flicker.patch,
    gdm-2.8.0.7-bg-4.patch,            gdm-2.8.0.7-domain-entry.patch,
    gdm-2.8.0.7-halt-needs-root.patch, gdm-2.8.0.7-onlyshow-in-gnome.patch,
    gdm-server-timeout.patch,          gdm-2.8.0.7-some-info-in-dialog.patch,
    gdm-gdmsetup.patch,                gdm-conf-custom-sysconfig.patch,
    gdm-2.19.3-reset-pam.patch,        gdm-2.19.3-dbus-security-tokens.patch,
    gdm-2.19.3-token-login.patch,      gdm-2.19.3-token-login2.patch,
    gdm-XKeepsCrashing-SaX2.patch,     gdm-XKeepsCrashing-desktop-effects.patch,
    gdm-language-hang.patch,           gdm-2.20.0-wait-for-restart.patch,
    gdm-bnc343858-buggy-intel-xinerama.patch.
* Thu May 15 2008 vuntz@suse.de
- Update gdm-xdm-sessions.patch to run /etc/X11/xdm/Xstartup. Part
  of bnc#368673.
* Wed Apr 16 2008 sbrabec@suse.cz
- Split package according to branding conventions (fate#301792).
- Removed branding related changes from gdm-conf.patch.
* Fri Apr  4 2008 dreveman@suse.de
- Add gdm-XKeepsCrashing-desktop-effects.patch. (bnc #359460).
* Wed Mar 19 2008 vuntz@suse.de
- Add gdm-bnc343858-buggy-intel-xinerama.patch to use gdk instead
  of direct xinerama functions. This will fix bnc343858 once we get
  the gtk+ patch in.
- Update gdm-gdmsetup-rootonly.patch
- Remove gdm-language-save.patch, abuild.patch and
  gdm-tab-triggers-enter.patch, fixed upstream.
- Update to version 2.20.4:
  + The Custom Widgetry code in gdmgreeter was broken, and would
    not create the /var/lib/$DISPLAY.GreeterInfo file properly
  + Now the default local and remote welcome strings ("Welcome" and
    "Welcome to %%n") are translated.
  + If the user picks the default local welcome string to be used
    as the remote welcome string, or vice versa, then the strings
    will be translated also.
  + Get default locale from LC_MESSAGES rather than from
    g_get_language_names.
  + Honor GTK+ default password character.
  + Provide better tooltip for entry field in gdmgreeter.
  + Get the environment variable XDG_DATA_DIRS before clearing the
    environment variables.
  + Fix gdmsetup bug that was causing the Welcome (local and
    remote) message to not be saved properly when changed.
  + Fix the setting of the custom command NOTIFY key to avoid
    crashing when changing the label values of a custom command in
    gdmsetup.
  + Fix compiler issues.
  + Translation updates.
- Changes from version 2.20.3:
  + Now "Esc" key acts like the "Start Again" button in the greeter
    program.
  + Fix regression in GDM 2.20 that caused the daemon to not read
    any [server-foo] sections that were not referenced in the
    [servers] section of the configuration file.
  + Fix regression in GDM 2.20 that caused HaltCommand,
    SuspendCommand, and RebootCommand to not get updated properly
    when modified from gdmsetup.
  + Allow the gdmflexiserver --command option to be run with
    setuid/setgid without problems
  + Fix counting of open XDMCP sessions.
  + Fix Suspend configuration option so it works.
  + Fix so that XDMCP Willing configuration option works.
  + Fix compiler warnings.
  + Fix gdmsetup so it does not crash if it cannot read any
    displays from the configuration file.
  + Translation updates.
- Changes from version 2.20.2:
  + Fix bugs that were causing XDMCP to not work properly.
  + Fix so that XDMCP configuration options are read from the
    configuration file.
  + Fix bug with gdmXnestchooser where it wasn't starting Xephyr
    with the correct arguments.
  + Fix so that GDM allows setting of LC_TYPE without setting LANG.
  + Icon improvements.
  + Fix leaks.
  + Translation updates.
- Changes from version 2.20.1:
  + gdmlogin and gdmgreeter treat Tab like enter if the focus
    is on the entry field.
  + Fix saving of user's default language/session if $HOME/.dmrc
    doesn't exist.
  + Fix bug with XDMCP logic.
  + Fix an issue that was causing the username to be logged as a
    debug message when using GDM configured to use crypt or shadow
    passwords.
  + Set stdout/stderr to DEV_NULL when spawning at_spi_registryd
    and the prefetch program, fixing a hanging problem.
  + GDM now always sends the daemon a response before exit to avoid
    a hang.
  + Fix gdmXnestchooser and gdmsetup so debug isn't on by default.
  + Updated the gdmgreeter themes to correctlt work on 800x600
    displays.
  + Build/configure fixes for Solaris.
  + Translation updates.
* Wed Nov 14 2007 hpj@suse.de
- Removed second --with-atspi-dir from configure.
- Added gdm-tab-triggers-enter.patch, which fixes Novell bug
  [#334446].
* Tue Nov 13 2007 rodrigo@suse.de
- Added --with-atspi-dir to configure to get accessible login
  (#337428)
- Updated gdm-xdm-sessions.patch to run again the /etc/X11/xdm
  scripts (#304399)
* Fri Nov  9 2007 hpj@suse.de
- Pass the --with-atspi-dir= flag to configure so the
  at-spi-registryd is started correctly. Fixes Novell bug #337428.
* Thu Oct 18 2007 maw@suse.de
- Install dbus-gdm.conf to /etc/dbus-1/system.d (#331725)
- Add abuild.patch.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Sep 24 2007 hpj@suse.de
- Added gdm-2.20.0-wait-for-restart.patch, which fixes Novell bug
  [#326281].
* Thu Sep 20 2007 banderso@suse.de
- added gdm-language-save.patch.  Patch fixes a problem where the
  .dmrc file was not getting created in the process of saving the
  default selected language.
  Novell bug #309066
* Tue Sep 18 2007 hpj@suse.de
- Updated gdm-2.8.0.0-any-hostname-auth.patch to use localhost
  instead of localhost.localdomain for xauth tokens. Related to
  Novell bug #304632.
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 2.20.0:
  * Now support --with-atspi-dir so you can specify a non-default
    directory where the at-spi-registryd daemon exists.
  * Improve keymouselistener a11y gesture listener so it does not
    fail on Ubuntu, and does a better job freeing memory.  Fix
    dwellmouselistener a11y gesture listener so it doesn't generate
    warnings.
  * Fix bug in IPv6 logic.
  * Fix Macedonian language so the language choice also appears in
    the local language
  * Fix bug where GDM was not properly executing a custom Xserver
    start script.
  * Fix bug with ConsoleKit that occurs when the session is going
    to migrate.  Previous code was failing to send the notification
    when the greeter is not TYPE_FLEXI.
  * Set invisible character to '*' for gdmgreeter.
  * When using gdm_verify_standalone_pam_conv (used by automatic
    login) set echo to FALSE when PAM_PROMPT_ECHO_OFF is handled.
  * Make it possible to configure system dependant options by
    setting environment variables before running configure.  Also
    support /usr/X11/bin/Xorg when setting X_PATH, etc.
  * Translation updates
* Mon Sep 17 2007 banderso@suse.de
- added patch gdm-language-hang.patch to fix Novell bugs #308378 and
  [#309064].  The patch matches changes that were made to upstream code.
* Fri Sep 14 2007 sreeves@suse.de
- Fix for Bug #308471 - gdm intentionally changed to storing the .desktop
  files under /usr/share/gdm which the suse_update_desktop_file script
  does not seem to fully support. It find the file, processes it, but
  does not write it out.
* Fri Sep 14 2007 hpj@suse.de
- Update gdm-2.8.0.7-halt-needs-root.patch to fix Novell bug
  [#306418].
* Thu Sep 13 2007 stbinner@suse.de
- '%%suse_update_desktop_file -G "" foo' doesn't seem to work anymore
* Wed Sep 12 2007 jberkman@novell.com
- correctly add localhost xauth for "remote" connections on little
  endian machines (bnc #296699)
* Wed Sep  5 2007 sbrabec@suse.cz
- Search for SaX2 in XKeepsCrashing.
* Wed Sep  5 2007 sbrabec@suse.cz
- Apply DISPLAYMANAGER_PASSWORD_LESS_LOGIN only for standard login,
  not for autologin (#307566).
* Mon Sep  3 2007 hpj@suse.de
- Add gdm-2.19.7-pam-hide-password.patch, which fixes an upstream
  bug where the user's password was being shown on screen (part of
  BNC #302282).
* Thu Aug 30 2007 maw@suse.de
- Update to version 2.19.7:
  + from 2.19.5 to 2.19.6:
- Fix gdmflexiserver so when used to start a "Nested Display" (a login
  in a window), it does not pop-up the window showing the user what
  VT's are already logged in.  That window should only show up when
  starting Flexi (VT) displays, not Nested displays.  (Brian Cameron)
- Remove XInput code from the dwellmouselistener accessibility module.
  Bug #457998 reported that this code was not working and causing
  devices to fail. (Ray Strode)
- Fix bug #461822 which caused entries in the [servers] section of the
  configuration to get ignored if more than one referenced the same
  [server-foo] server.  This was working in 2.18 but got broken during
  the cleanup.  (Brian Cameron)
- Fix gdm_fail function so that it cleans up and exits, so now GDM
  will better handle critical failures.  This was working in 2.18
  but got broken during the cleanup.  (Brian Cameron)
- Now gdmsetup sets "Use 24 Hour Clock" to "yes" when this is its
  value.  (Sebastien Bacher)
- Fixes for utmpx processing so it now works with utmp and also on
  FreeBSD.  (Brian Cameron, Joe Marcus Clarke)
- Fix IPv6 check when starting VT so that if IPv6 reports that the
  network is not reachable, it falls back to IPv4.  (Brian Cameron)
- Fix string translation issues.  (Lukasz Zalewski)
- From 2.19.6 to 2.19.7:
- Disable autocompletion in the face browser since it wasn't
  working properly.  (Ray Strode)
- Many corrections to the theme xml files  (Dave Fincher and Brian
  Cameron)
- Fix compile when using a compiler that doesn't like #ifdefs
  in macro calls.  (Jens Granseuer)
- The greeter.dtd file has been updated.  Now the default GDM themes
  validate with this dtd.  (Dave Fincher)
- Plus translation updates for a plethora of locales.
* Thu Aug 16 2007 hpj@suse.de
- Fixed missing configuration variable definition in
  gdm-2.8.0.7-domain-entry.patch.
* Fri Aug 10 2007 sbrabec@suse.cz
- Patches are enabled again, re-enabled gnome-patch-translation.
* Thu Aug  9 2007 sbrabec@suse.cz
- Re-added DISPLAYMANAGER_PASSWORD_LESS_LOGIN to SuSEconfig.gdm
  (#279426).
- Allow password less login for both autologin and standard login.
* Tue Aug  7 2007 jpr@suse.de
- Split off a -lang subpackag
- Fix variable expansion in gdm-conf.patch (#255685)
- Remove earlygdm, replaced by earlyxdm (#285813)
* Sat Aug  4 2007 maw@suse.de
- Use %%fdupes
- Uncomment out the rm in %%clean.
* Sat Aug  4 2007 hpj@suse.de
- Update to version 2.19.5.
- Fix up gdm-conf.patch.
- Fix up gdm-2.19.3-reset-pam.patch.
- Fix up gdm-2.19.3-token-login.patch.
- Fix up and enable gdm-language-dialog-size.patch.
- Fix up and enable gdm-2.8.0.7-bg-4.patch.
- Fix up and enable gdm-2.8.0.7-domain-entry.patch.
- Fix up and enable gdm-2.8.0.7-halt-needs-root.patch.
- Fix up and enable gdm-server-timeout.patch.
- Fix up and enable gdm-2.8.0.7-some-info-in-dialog.patch.
- Fix up and enable gdm-2.17.7-vt-fallback.patch.
- Fix up and enable gdm-2.8.0.0-any-hostname-auth.patch.
- Remove gdm-2.19.3.diff (upstreamed).
- Remove gdm-2.13.0.4-audit-login.patch (upstreamed).
- Remove gdm-logdir.patch (fixed upstream).
- Remove gdm-bash-profile.patch (obsolete).
* Mon Jul 30 2007 jberkman@novell.com
- use smartcard pam stack when cards are inserted
* Wed Jul 25 2007 jpr@suse.de
- Re-enable gdm-xdm-sessions.patch (#294498)
* Tue Jul 24 2007 jpr@suse.de
- Add xorg-x11-server-extras for Xnest/Xephyr so that the defaults
  are set correctly (not an installation dep)
* Thu Jul 19 2007 maw@suse.de
- Reenable gdm-conf.patch (#292837).
* Tue Jul 17 2007 coolo@suse.de
- fix pointer arithmetic
* Mon Jul 16 2007 mauro@suse.de
- Update to version 2.19.3
- Clean up of the not applicable patches.
- Bugfixes for #448547, #448548, #443557.
* Sat May 26 2007 jpr@suse.de
- Require xorg-x11-server-extra for Xnest
* Tue May 15 2007 pgajdos@suse.cz
- removed BuildRequires: gnome-icon-theme [#247450]
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Wed Apr 11 2007 maw@suse.de
- Update to version 2.18.1
- The GDM configuration option daemon/PidFile is now deprecated and
  GDM now always uses /var/run/gdm.pid.  The location can be configured
  at compile time with the configure --with-pid-file option.  This
  fixes bug #162849.  (William Jon McCann)
- Now GDM supports Xephyr as the Nested Xserver command.  GDM will use
  Xephyr by default if it is on the system, and fallback to Xnest.
  Xephyr works much better than Xnest.  (Brian Cameron)
- GDM application desktop files now use the correct categories, so the
  menu choices should appear in the correct place in the menu.  (Brian
  Cameron)
- Remove the userlist from the circles and happygnome themes since this
  was causing problems for some users.  This change will go into 2.20
  where we are fixing the problem better by fixing gdmsetup to support
  setting the configuration so that gdmlogin and gdmgreeter work the
  same way with the Browser key.
- Now gdmgreeter has an ATK label for the entry field.  (David Zeuthen)
- Fix check so language combo style works.  Fixes bug #423063.  (Simon)
- Now "Configure GDM" menu choice is not available when accessibility is
  turned on since running gdmsetup in this configuration causes GDM to
  hang.  Until the hanging bug is fixed, it's better to not allow the
  user to get into this situation.  (Brian Cameron)
- Now support XnestUnscaledFontPath configuration option, which allows
  GDM to work with Xnest.  Xorg 7.2 XGetFontPath function now returns
  fontpath with the ":unscaled" prefix, which Xsun Xnest cannot handle.
  Setting XnestUnscaledFontPath=false, will strip the ":unscaled" prefix
  from the fontpath so that it can work.  (Brian Cameron)
- GDM daemon no longer links with D-Bus if ConsoleKit is not enabled.
  (William Jon McCann)
- Translation updates (Takeshi AIHANA, Jakub Friedl, Leonardo Ferreira
  Fontenelle, Pema Geyleg, Priit Laes, Kjartan Maraas, Inaki Larranaga
  Murgoitio, Kostas Papadimas, Ignacio Casal Quinteiro, Hendrik Richter,
  Changwoo Ryu, Claudio Saavedra)
* Fri Mar 30 2007 maw@suse.de
- Update to version 2.18.0
- b.g.o 415513, 417350, 415181, 409801, 409693, 406226, and 407687.
* Fri Mar 30 2007 aj@suse.de
- Add pwdutils to BuildRequires.
* Wed Mar 21 2007 hpj@suse.de
- Add gdm-2.17.7-vt-fallback.patch. This is a port of the fix for
  https://bugzilla.novell.com/show_bug.cgi?id=206804
* Tue Mar 13 2007 maw@suse.de
- Update to version 2.17.7
- Removeupstreamed  gdm-autobuild-warning.patch,
  gdm-bufferoverrun.patch
- Bug fixes, including bugzilla.gnome.org #335786, #400793,
  [#400698], #399486, #352263, #395790, #394421.
* Fri Mar  2 2007 sbrabec@suse.cz
- Do not own /usr/share/xsessions (#229172).
* Tue Feb 27 2007 hpj@suse.de
- Added gdm-2.13.0.4-audit-login.patch, which fixes Novell bug
  [#234133] (GDM cannot log authentication attempts).
* Wed Feb 14 2007 hpj@suse.de
- Add gdm-trunk-string-literal-cmp.patch. Fixes #233655.
* Mon Feb 12 2007 sbrabec@suse.cz
- Fixed reversed interpretation of
  DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN (221350#c11).
* Fri Feb  9 2007 crivera@suse.de
- Add PreReq for insserv and ensure that we always enable
  earlygdm in the post-install script.  This fixes 192998.
* Wed Jan 31 2007 sbrabec@suse.cz
- Fixed PreReq for /etc/init.d/xdm in older products.
* Tue Jan 23 2007 sbrabec@suse.cz
- Update /etc/init.d/xdm on older products.
* Thu Jan  4 2007 sbrabec@suse.cz
- All references to /opt/gnome moved to /usr.
- Spec file cleanup.
* Thu Jan  4 2007 maw@suse.de
- Move to /usr.
* Thu Dec 28 2006 jhargadon@suse.de
- added klogd to Requires (#214295)
* Tue Dec 12 2006 sbrabec@suse.cz
- Fixed SuSEconfig typo in XDMCP Enable (#221350).
* Mon Dec 11 2006 maw@suse.de
- Add gdm-bufferoverrun.patch, fixing a format string exploit
  (#226360).
* Thu Nov 30 2006 jhargadon@suse.de
- removed unneeded files from the package (#223687)
* Tue Nov 21 2006 jpr@suse.de
- Fix missing comment in config file (rest of #221383)
* Fri Nov 17 2006 jpr@suse.de
- Fix where last_domain is saved (#221543)
* Thu Nov 16 2006 danw@suse.de
- Remove the ssh session, which has never worked correctly on SUSE.
  [#220731]
* Wed Nov  8 2006 hpj@suse.de
- Update and re-enable gdm-bash-profile.patch.
- Update and re-enable gdm-2.8.0.0-setup-no-flicker.patch.
- Drop gdm-2.8.0.0-timed-login-enact.patch (similar fix upstream).
- Update and re-enable gdm-2.8.0.7-domain-entry.patch.
- Update and re-enable gdm-2.8.0.7-hald-needs-root.patch.
- Drop gdm-2.8.0.7-user-must-own-iceauthority (upstream).
- Update gdm-autobuild-warning.patch (conflict with previous patch).
* Tue Oct 31 2006 sbrabec@suse.cz
- Rewritten SuSEconfig.gdm to work better with new custom.conf
  (#213037).
* Fri Oct 27 2006 jhargadon@suse.de
- changed TryExec to be the same as Exec in gdmsetup.desktop to
  resolve bug #210943
* Mon Oct 23 2006 jhargadon@suse.de
- mkdir /var/log/gdm (#213737)
* Thu Oct 12 2006 danw@suse.de
- Remove some dead patches. Rename a few for consistency
- Update and re-enable gdm-server-timeout.patch
- Update and re-enable gdm-logdir.patch (#211223)
- Add gdm-X_SERVER.patch to fix Xorg/Xgl switching
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- Use g_markup_printf_escaped so gdmsetup better handles
  description strings that contains things similar to a tag
  like an email address
- Fix gdmsetup so that the window manager close button works
  as the Close button in the dialog
- Fix for bug #352838, avoid crashing by moving call to get
  GDM_KEY_SYSTEM_MENU until after authentication check.
- Add g_type_init() to gdmflexiserver since this is needed
  for -a (authentication) code to work.
- Translation updates
* Tue Sep 26 2006 jhargadon@suse.de
- removed am_devperm.so from gdm.pamd and gdm-autologin.pamd
  to resolve bug #206963
* Wed Sep 20 2006 jhargadon@suse.de
- modified SuSEconfig.gdm to reflect the name change of gdm.conf
  to custom.conf.  bug #206904
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- Minor improvements to SDTLOGIN logic, used on Solaris to drop the
  Xserver to user permissions for added security
- Translation updates
- 327530 - Ensure login window always has focus.
- 341619 - No longer save "Failsafe" sessions as user's default login
* Mon Sep  4 2006 kukuk@suse.de
- Add pam_loginuid.so to gdm.pamd and gdm-autologin.pamd
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.10
- Now gdmlogin centers cursor in the GUI to ensure that the login
  window always has focus
- Translation updates
* Thu Aug 24 2006 sbrabec@suse.cz
- Include xorg-x11-server to BuildRequires to properly detect Xorg
  version (#201125).
- Enabled parallel build.
- Enabled secure remote session support.
* Wed Aug 23 2006 jhargadon@suse.de
- update to version 2.15.9
- Fix so that focus never leaves the user/password entry when using
  the gdmgreeter Options button.
- Fix error message that gets printed when you try to run GDM
  daemon as a non-root user.
- Remove calls to syslog/malloc that are called from inside signal
  handlers, since they are not safe.
- Translation updates
- Fix to bugs causing gdmchooser to core dump when started.
* Thu Aug 10 2006 jhargadon@suse.de
- update to version 2.15.7
- Now GDM does not save Failsafe GNOME or Failsafe Xterm as the
  user's default session
- Updated GDM's slave/daemon message handling so it uses
  giochannel internal buffering.
- Performance improvements to gdmsetup start-up.
- Translation updates
- Timed Login message fixed so it works when TimedLogin is set to a
  piped script.
- Fix decoding of suspend command so it works.
- Make sure that focus is returned to entry after dialogs are launched
  from the new Options button.
- NoHost icon updated to use official GNOME logo.  New default face
  image with a facelift.
- Scrolling regions in gdmsetup User tab are now scrollable
  vertically, improving UI experience.
- Correction to autologin PAM service name so automatic login works.
- Fix compiler warnings that were causing core dumping issues on
  some platforms
- Correction for serious security issue where the user can enter the
  GDM configuration GUI with a user password when the Face Browser
  is enabled.
- Fixed bug where when the "Include All" button is modified in the
  Users tab, the Automatic/Timed login dropdown lists update
  properly.
- Now gdmflexiserver calls gdmcomm_check with FALSE so it will not
  pop up a dialog.
- Added gestures to the AccessKeyMouseEvents configuration file
  so that users can access more accessibility features using
  dwell gestures.
- Now Welcome message is saved in the configuration file in
  UTF-8 format for better readibility.
- Improvements to Face Browser.
- Now when GTK+ style buttons are used in gdmgreeter themes,
  focus always returns to the entry field after clicking on
  a button.
- Now per-display configuration works for greeter/SystemMenu
  and greeter/ChooserButton keys.
- "make install" no longer fails if chown fails.
- If authdir is the fallback dir.  If not, and GDM cannot
  access the user's $HOME directory, then try and use the
  fallback directory.
- No longer use popt in favor of glib's GOption command line parsing.
- Fix bug that was causing ShowGnomeFailsafeSession and
  ShowGnomeXtermSession configuration values to not work.
- Now add gdm-ssh-session to distribution tarball, and fix the
  ssh-session.desktop file so that it sets the right TryExec
  value even if --libexecdir isn't passed into configure.
- Fix layout of new buttons in gdmgreeter themes.
- Improvements to signal handling, fixing problem where GDM slave can
  hang on read.
- Better configure support for FreeBSD.
- Fix security/AllowRemoteAutoLogin and fix SuspendCommand configuration
  so it honors SystemMenu.
- Explicitly adjust the effective GID before running the child session
  program to avoid remaining with high privileges.
- Now allow the PAM Stack to be specified in the GDM configuration instead
  of being hardcoded to "gdm"
- Per-display configuration is now supported.
- Greeter themes now support real GTK+ button types, making gdmgreeter
  better support a11y and allow GTK themeable buttons.
* Fri Jun  9 2006 hpj@suse.de
- Update domain entry patch to default to the currently joined
  Active Directory domain if there was no stored preference. Fixes
  Novell bug #167344.
* Wed May 31 2006 hpj@suse.de
- Don't let any user configure GDM from the login screen if a
  theme with user list is in effect. Fixes Novell bug #180219.
* Wed May 31 2006 dreveman@suse.de
- Fix bg patch and change gdm.conf patch so we pass -br to X
  server for black root window. (bnc 179847)
* Wed May 24 2006 sbrabec@suse.cz
- Do not display Japanese string in terminal, which doesn't support
  it (#168736).
- Disabled beep on start (#174786).
* Fri May 19 2006 hpj@suse.de
- Made GDM use the more graphically intensive, but prettier,
  gdmgreeter for remote logins. Fixes Novell bug #176661.
* Tue May 16 2006 sbrabec@suse.cz
- Do not require exact UID 50 (it can fail, if already assigned).
- Do not fail, if group gdm already exists.
- Behave properly, if gdm.conf defines server 1 (#175829).
* Fri May 12 2006 sbrabec@suse.cz
- Store value of PERMISSION_SECURITY by SuSEconfig in
  gdm_sysconfig.conf (169639#c20).
* Tue May  9 2006 hpj@suse.de
- Made GDM use the "gdm" group instead of shadow. Fixes Novell bug
  [#119651].
- Made use of the tab key work like pressing enter if there is no
  other entry to tab to. Part of fix for Novell bug #160879 and
  [#167343].
- Made use of the enter key in the domain entry work like it does
  in the user/password entry. Par of fix for Novell bug #160879
  and #167343.
* Wed Apr 26 2006 hpj@suse.de
- Added patch to show info messages in dialog. Needed for AD,
  resolves bug #162146.
* Mon Apr 10 2006 hpj@suse.de
- Update .ICEauthority fixup patch, corrects serious security
  problem (bug #164520).
* Fri Apr  7 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Thu Apr  6 2006 hpj@suse.de
- Add patch to fix logic for .ICEauthority permissions correction.
  Fixes bug #162952.
* Fri Mar 31 2006 jpr@suse.de
- Extend gdm timeout to 30 seconds, 10 seconds is too short for the
  ATI driver to respond under Xgl
* Mon Mar 20 2006 federico@novell.com
- Fixed uninstallation of symbolic links for the earlygdm startup
  service, bug #158786.
* Sat Mar 11 2006 coolo@suse.de
- fix the only-show-in-gnome patch to patch the .desktop.in
* Tue Mar  7 2006 federico@novell.com
- Fix installation of the earlygdm service; we were not calling
  fillup_and_insserv with "displaymanager" for the configuration
  filename.
* Wed Mar  1 2006 sbrabec@suse.cz
- KDM_SHUTDOWN renamed to DISPLAYMANAGER_SHUTDOWN, use fillup only
  in PLUS (148468#c17).
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 24 2006 hpj@suse.de
- Add patch to fix tab keynav.
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Fri Feb 17 2006 gekker@suse.de
- Fix background color in GDM, it should be black
* Fri Feb 17 2006 sbrabec@suse.cz
- Added sysconfig fillup template (148468#c15).
* Mon Feb 13 2006 sbrabec@suse.cz
- Implemented KDM_SHUTDOWN to SuSEconfig.gdm (#148468).
- Set AllowRemoteRoot=false in gdm.conf to follow default
  sysconfig.
* Mon Feb 13 2006 hpj@suse.de
- Updated shutdown options patch: Whether to allow shutdown,
  and whether this requires root auth, are the two new options.
- Enforce shutdown options on logout as well.
* Fri Feb 10 2006 coolo@suse.de
- don't show gdm desktop files in KDE
- use the new way to call preload
* Mon Feb  6 2006 sbrabec@suse.cz
- Implemented DISPLAYMANAGER_AD_INTEGRATION to SuSEconfig.gdm
  (#139338).
* Mon Feb  6 2006 hpj@suse.de
- Updated domain entry patch to use --all-domains with wbinfo.
- Updated domain entry patch to show "<Local>" for local login.
- Added patch to require root auth to halt or reboot.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 hpj@suse.de
- Updated the domain logon patch with numerous new features and
  cosmetic fixes.
* Mon Jan 16 2006 hpj@suse.de
- Fixed a bug in logon code that prevented domain logons from
  working. Updated domain logon patch.
* Fri Jan 13 2006 schwab@suse.de
- Don't strip binaries.
* Tue Jan 10 2006 hpj@suse.de
- Added domain logon patch for ADS.
* Mon Dec  5 2005 gekker@suse.de
- Updated background patch from David Reveman
* Wed Nov 30 2005 gekker@suse.de
- Update o version 2.8.0.7
- Remove upstream patch
- Fixup patch for background colors
* Thu Nov 10 2005 rml@suse.de
- Add earlygdm init script.  Right now, we just preload gnome bits.
* Wed Nov  2 2005 gekker@suse.de
- Fix so ctrl-alt-backspacing restarts the xserver (#113718)
- Patch from upstream b.g.o (#152906)
* Mon Oct 17 2005 gekker@suse.de
- Make gdm.conf %%config(noreplace)
* Fri Oct 14 2005 hpj@suse.de
- Updated xauthority-across-hostname-changes patch to use
  XAUTHLOCALHOSTNAME environment variable.
* Thu Oct 13 2005 gekker@suse.de
- Update to version 2.8.0.5
* Tue Oct  4 2005 gekker@suse.de
- Rediff patch for background colors
* Tue Oct  4 2005 gekker@suse.de
- Fix background colors to be consistent on startup
* Tue Sep 20 2005 sbrabec@suse.cz
- Removed references to build directory in installed .la files.
* Thu Sep 15 2005 gekker@suse.de
- Make Industrial the default Gtk+ theme (114173)
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 2.8.0.4.
* Mon Aug 22 2005 gekker@suse.de
- Update to version 2.8.0.3
- Remove upstreamed autologin patch
- Now installs .desktop files in correct location no need to move
* Sat Aug 20 2005 hpj@suse.de
- Make the default session option work on autologin; we now get GNOME.
* Tue Aug 16 2005 sbrabec@suse.cz
- Use gnome-screensaver instead of xscreensaver.
* Fri Aug 12 2005 hpj@suse.de
- Made gdm-autologin.pam not require a password.
* Fri Aug 12 2005 jpr@suse.de
- require xorg-x11-xnest for the gdmflexiserver -n option
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.8.0.2
- Make 64bit clean
* Sun Jul 31 2005 jpr@suse.de
- turn on compatibility symlink for all products
* Tue Jul  5 2005 gekker@suse.de
- Update to version 2.8.0.1
- Do not use hostname in authentication cookie (82688).
- Disabling of "timed login" doesn't work (8060).
- Issues with "timed login" being set to zero (8024).
- Display flickers for every letter typed (6354).
* Fri Jun 24 2005 sbrabec@suse.cz
- Added compatibility symlink %%{prefix}/bin/gdm for older products.
* Wed Jun 22 2005 gekker@suse.de
- Update to version 2.8.0.0
* Fri Apr 22 2005 sbrabec@suse.cz
- Implemended DISPLAYMANAGER_PASSWORD_LESS_LOGIN using SuSEconfig
  and PAM configuration (#74198).
* Fri Apr 22 2005 sbrabec@suse.cz
- Fixed logdir (#56205).
* Mon Mar 21 2005 jody@suse.de
- Fix typo in upstream package that broke Shutdown
- Repaired Suspend command to actually work
* Fri Mar 18 2005 sbrabec@suse.cz
- Removed X-Ximian-Settings (#73047).
* Wed Mar 16 2005 sbrabec@suse.cz
- Fixed capplets desktop files path.
- Added X-Ximian-Settings to gdmsetup and gdmphotosetup (#73047).
* Tue Mar 15 2005 sbrabec@suse.cz
- Fixed X-KDE-RootOnly in gdmsetup.desktop (#66693).
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.6.0.8 (GNOME 2.10).
* Fri Feb 18 2005 sbrabec@suse.cz
- Remove gdm_sysconfig.conf before update to force gdm.conf configuration.
* Fri Feb 11 2005 sbrabec@suse.cz
- Resource only /usr/share/xsessions for session desktop files.
- Fixed tcp_wrappers support on bi-arch.
* Thu Feb 10 2005 gekker@suse.de
- Update to version 2.6.0.7
* Wed Feb  9 2005 sbrabec@suse.cz
- Cleaned-up configuration and patches.
- Prepared moving of session files to windowmanager packages.
* Tue Feb  8 2005 gekker@suse.de
- Add patch back to fix Xsession file
* Mon Jan 24 2005 meissner@suse.de
- added missing NULL in a g_strconcat.
* Thu Jan 20 2005 gekker@suse.de
- Update to version 2.6.0.6
* Wed Nov 17 2004 hhetter@suse.de
- add X-KDE-RootOnly to gdmsetup.desktop (#45807)
* Mon Nov 15 2004 kukuk@suse.de
- Use common-* PAM config files for gdm and gdm-autologin
* Tue Oct 26 2004 mmj@suse.de
- Locale rename no to nb
* Fri Oct 15 2004 sbrabec@suse.cz
- Implemented sysconfig displaymanager support.
* Fri Sep 24 2004 hhetter@suse.de
- gdm must require gnome-themes, to ensure availability of
  the industrial theme (#44330)
* Wed Aug 25 2004 clahey@suse.de
- Cache gdm help and show gdm in khelpcenter.
* Mon Aug 16 2004 ro@suse.de
- fixed specfile
* Mon Aug 16 2004 shprasad@suse.de
- Fixes bug #60020
  Invalid username/passwd input doen't bring the password dialog
  for timed login user.
* Fri Jul 30 2004 ro@suse.de
- fix spec file, list gdm-session-startkde.diff as patch
* Fri Jul 30 2004 shprasad@suse.de
- Fixes bug #60867.
  Shows the 'KDE' option when the user clicks on 'Session' at the
  time of login.
  (In the spec file, the diff file, gdm-session-startkde.diff, is
  applied at the %%install section)
* Wed Jun 23 2004 dave@suse.de
- Added gdm-presession-kde-path.patch, adds /opt/kde3/bin to the
  gdm path
* Fri Jun 11 2004 clahey@suse.de
- Added gdm-support-gdmctl.patch.
* Wed Jun  2 2004 mibarra@suse.de
- Fixed gdm.conf to use the correct group
* Wed Jun  2 2004 clahey@suse.de
- Set theme to industrial (as well as a few other small changes.)
* Fri May  7 2004 hhetter@suse.de
- updated to version 2.6.0.0 [GNOME2.6]
* Wed Mar 31 2004 hhetter@suse.de
- startup in graphical theme (#37668)
- Require gnome2-SuSE for the Default Theme (#37707)
- honor xdm scripts (#37852)
* Tue Mar 23 2004 sbrabec@suse.cz
- Non-UTF-8 locales removed from language menu.
* Mon Mar 22 2004 hhetter@suse.de
- remove SuSEconfig.gdm; it's no longer needed to manage
  the available sessions for gdm, as it is now using desktop
  files to define it's sessions (#36267)
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed %%doc attributes (#33163).
* Tue Mar  9 2004 hhetter@suse.de
- include desktop files for sessions
* Tue Mar  2 2004 hhetter@suse.de
- updated to version 2.4.4.7 [GNOME 2.4.2]
- applied adapted bash-login-shell patch
- adapted desktop file patch
- adapted configuration file (use tools from powersave)
* Thu Feb 26 2004 hhetter@suse.de
- attached patch: gdm-2.4.1.6-bash-login-shell.patch,
  make sure a login shell is available when using
  bash
* Fri Feb 20 2004 sbrabec@suse.cz
- Package renamed to gdm.
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Sep 18 2003 adrian@suse.de
- add Categories
- show entries only in Gnome (#31287)
* Fri Sep  5 2003 hhetter@suse.de
- added Obsoletes: gdm
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated neededforbuild (rename of librsvg2, eel2).
* Tue Aug 12 2003 hhetter@suse.de
- updated to version 2.4.1.6
* Mon Jul 28 2003 kukuk@suse.de
- Make sure /var/lib/gdm has correct permissions
* Thu Jul 24 2003 hhetter@suse.de
- move capplets to correct position
- fix build
* Wed Jul 16 2003 sbrabec@suse.cz
- Fixed prefix in configuration files.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated to version 2.4.1.4.
- Fixed default path to Xwilling.
- Updated neededforbuild.
- Use %%find_lang.
- Prefix clash fix (capplets).
* Tue May 27 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon May 26 2003 sbrabec@suse.cz
- Re-enabled UTF-8 alternatives for all locales.
* Sun Mar 16 2003 adrian@suse.de
- add resmgr support to pam
* Mon Mar 10 2003 hhetter@suse.de
- use LC_MESSAGES instead of LC_ALL for setlocale
  ( Bug Id#24889 )
* Thu Feb 27 2003 sbrabec@suse.cz
- Removed gdm wrapper (fixes problems with default language and init
  script - bug #23875).
* Tue Feb 25 2003 sbrabec@suse.cz
- Don't offer UTF-8 locales.
* Mon Feb 24 2003 hhetter@suse.de
- use graphical greeter by default
* Thu Feb 20 2003 sbrabec@suse.cz
- Use system language for GDM login from /etc/sysconfig/language.
* Tue Feb 18 2003 sbrabec@suse.cz
- Updated default config and locale aliases (UTF-8 locales).
* Fri Feb  7 2003 hhetter@suse.de
- updated to 2.4.1.3 [GNOME 2.2.0]
* Fri Feb  7 2003 kukuk@suse.de
- Use pam_unix2.so instead of pam_unix.so
* Wed Jan 15 2003 ro@suse.de
- use gtk2-devel-packages and libjpeg in neededforbuild
* Tue Jan  7 2003 sbrabec@suse.cz
- Update to version 2.4.1.0.
- Make Default session file executable.
- Added UTF-8 as alternative for all locales.
- Turned on TCP wrappers support.
* Mon Jan  6 2003 sbrabec@suse.cz
- Install SuSE specific PAM configuration (from xdm), fix its install
  place.
- Removed sox from neededforbuild.
* Thu Nov 28 2002 hhetter@suse.de
- updated to version 2.4.0.12 [GNOME 2.0.3]
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Sun Nov  3 2002 mfabian@suse.de
- Bug Id #21407: correct wrong spelling of UTF-8 locale names
  in /etc/opt/gnome2/gdm/locale.alias. de_DE.utf8 was used
  instead of de_DE.UTF-8 etc., but de_DE.UTF-8 is not supported
  by X11, although de_DE.utf8 and de_DE.UTF-8 is the same
  as far as glibc is concerned, the correct spelling is important
  for X11.
- Bug Id #21408: When using gdm2 the usual intialization file
  of an X session, i.e. ~/.xinitrc, ~/.xsession, ~/.Xmodmap
  ~/.xim etc. were not read. Because of this, inputservers for CJK
  languages did not start automatically and other default
  settings were not correct either.
  I fixed this by improving /etc/opt/gnome2/gdm/Sessions/Default
  to use 'exec /etc/X11/xdm/Xsession $WINDOWMANGER $GDM_LANG'.
  This makes the default behaviour when using gdm2 the same
  as when using kdm or xdm.
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Thu Sep  5 2002 hhetter@suse.de
- updated to version 2.4.0.11, fixing a security issue
  (no longer open the logging file descriptor as root in
  slave.c ) ( Bug Id #18908 )
* Mon Sep  2 2002 hhetter@suse.de
- if no session was chosen or previously saved, choose
  the gnome session ( Bug Id #18729)
* Fri Aug 30 2002 hhetter@suse.de
- fix default script and session linking (Bug Id#18602)
* Thu Aug 22 2002 hhetter@suse.de
- parse correct Session directory (Bug Id#18181)
* Tue Aug 20 2002 hhetter@suse.de
- fix prereq
* Mon Aug 12 2002 hhetter@suse.de
- updated to version 2.4.0.7
- fix neddedforbuild
* Wed Aug  7 2002 hhetter@suse.de
- updated to version 2.4.0.5
- fix typo in SuSEconfig script (#17438)
- fix linking of sessions
* Wed Jul 17 2002 hhetter@suse.de
- updated to version 2.4.0.2
  * busy cursor when start X
  * 'System Default' language choice
  * fix unresponsive behaviour when first asking for
  username in graphical greeter #83187 (bugzilla.gnome.org)
  * 'Last' language choice in graphical greeter
  * 24 hour clock setting in graphical greeter
  * Happy Gnome Theme Update
  * more languages supported #84290 (bugzilla.gnome.org)
  * Translation updates
* Thu Jul 11 2002 hhetter@suse.de
- fix default session
- activate graphical gdmgreeter for local logins by default
* Wed Jul 10 2002 hhetter@suse.de
- updated to version 2.4.0.1, bugfix release
- SuSEconfig.gdm2 to manage the GDM sessions
* Tue Jul  9 2002 hhetter@suse.de
- initial SuSE package
- create gdm user
